@@ -19,7 +19,7 @@
 #include <tqaccel.h>
 #include <tqcursor.h>
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #else
@@ -49,7 +49,7 @@ KFullscreenVideoWidget::KFullscreenVideoWidget( KVideoWidget *parent, const char
 {
     this->videoWidget = parent;
     setEraseColor( black );
-    setCursor(TQCursor(Qt::BlankCursor));
+    setCursor(TQCursor(TQt::BlankCursor));
 }
 
 void KFullscreenVideoWidget::windowActivationChange( bool )
@@ -62,7 +62,7 @@ void KFullscreenVideoWidget::windowActivationChange( bool )
 
 bool KFullscreenVideoWidget::x11Event( XEvent *event )
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     if (event->type == ClientMessage &&
 	event->xclient.message_type ==
 		XInternAtom( tqt_xdisplay(), "VPO_RESIZE_NOTIFY", False ))
@@ -102,16 +102,16 @@ void KVideoWidget::init(void)
 
     // Setup actions
     new TDEToggleAction( i18n("Fullscreen &Mode"), "view-fullscreen",
-		       CTRL+SHIFT+Key_F, TQT_TQOBJECT(this), TQT_SLOT(fullscreenActivated()),
+		       CTRL+SHIFT+Key_F, this, TQ_SLOT(fullscreenActivated()),
 		       actionCollection(), "fullscreen_mode" );
     new TDERadioAction( i18n("&Half Size"), ALT+Key_0,
-		      TQT_TQOBJECT(this), TQT_SLOT(halfSizeActivated()),
+		      this, TQ_SLOT(halfSizeActivated()),
 		      actionCollection(), "half_size" );
     new TDERadioAction( i18n("&Normal Size"), ALT+Key_1,
-		      TQT_TQOBJECT(this), TQT_SLOT(normalSizeActivated()),
+		      this, TQ_SLOT(normalSizeActivated()),
 		      actionCollection(), "normal_size" );
     new TDERadioAction( i18n("&Double Size"), ALT+Key_2,
-		      TQT_TQOBJECT(this), TQT_SLOT(doubleSizeActivated()),
+		      this, TQ_SLOT(doubleSizeActivated()),
 		      actionCollection(), "double_size" );
 
     ((TDEToggleAction *)action( "half_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
@@ -191,7 +191,7 @@ void KVideoWidget::embed( Arts::VideoPlayObject vpo )
 
 TQImage KVideoWidget::snapshot( Arts::VideoPlayObject vpo )
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     Window root;
     Pixmap pixmap;
     XImage *xImage;
@@ -306,7 +306,7 @@ void KVideoWidget::mousePressEvent( TQMouseEvent *event )
 	emit mouseButtonPressed( event->button(), pos, event->state() );
 
 	// ### Remove in KDE4
-	if ( event->button() == Qt::RightButton )
+	if ( event->button() == TQt::RightButton )
 		emit rightButtonPressed( pos );
 }
 
@@ -358,7 +358,7 @@ void KVideoWidget::resizeNotify( int width, int height )
 
 bool KVideoWidget::x11Event( XEvent *event )
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined TQ_WS_X11 && ! defined K_WS_QTONLY
     if (event->type == ClientMessage &&
 	event->xclient.message_type ==
 		XInternAtom( tqt_xdisplay(), "VPO_RESIZE_NOTIFY", False ))
@@ -379,20 +379,20 @@ void KVideoWidget::fullscreenActivated()
 	fullscreenWidget = new KFullscreenVideoWidget( this );
 
 	// Interconnect mouse button signals
-	connect( fullscreenWidget, TQT_SIGNAL(mouseButtonPressed( int, const TQPoint &, int )),
-		 this, TQT_SIGNAL(mouseButtonPressed( int, const TQPoint &, int)) );
+	connect( fullscreenWidget, TQ_SIGNAL(mouseButtonPressed( int, const TQPoint &, int )),
+		 this, TQ_SIGNAL(mouseButtonPressed( int, const TQPoint &, int)) );
 
-	connect( fullscreenWidget, TQT_SIGNAL(mouseButtonDoubleClick( const TQPoint &, int )),
-		 this, TQT_SIGNAL(mouseButtonDoubleClick( const TQPoint &, int )) );
+	connect( fullscreenWidget, TQ_SIGNAL(mouseButtonDoubleClick( const TQPoint &, int )),
+		 this, TQ_SIGNAL(mouseButtonDoubleClick( const TQPoint &, int )) );
 
 	// ### Remove in KDE4
-	 connect( fullscreenWidget, TQT_SIGNAL(rightButtonPressed(const TQPoint &)),
-		this, TQT_SIGNAL(rightButtonPressed(const TQPoint &)) );
+	 connect( fullscreenWidget, TQ_SIGNAL(rightButtonPressed(const TQPoint &)),
+		this, TQ_SIGNAL(rightButtonPressed(const TQPoint &)) );
 		 
 	// Leave fullscreen mode with <Escape> key
 	TQAccel *a = new TQAccel( fullscreenWidget );
 	a->connectItem( a->insertItem( Key_Escape ),
-			this, TQT_SLOT(setWindowed()) );
+			this, TQ_SLOT(setWindowed()) );
 
 	fullscreenWidget->setFocus();
 	fullscreenWidget->showFullScreen();
