@@ -38,8 +38,8 @@ Suppose that you need list of web servers running. Example:
 
 \code
 DNSSD::ServiceBrowser* browser = new DNSSD::ServiceBrowser("_http._tcp");
-connect(browser,TQT_SIGNAL(serviceAdded(RemoteService::Ptr)),this,TQT_SLOT(addService(RemoteService::Ptr)));
-connect(browser,TQT_SIGNAL(serviceRemoved(RemoteService::Ptr)),this,TQT_SLOT(delService(RemoteService::Ptr)));
+connect(browser,TQ_SIGNAL(serviceAdded(RemoteService::Ptr)),this,TQ_SLOT(addService(RemoteService::Ptr)));
+connect(browser,TQ_SIGNAL(serviceRemoved(RemoteService::Ptr)),this,TQ_SLOT(delService(RemoteService::Ptr)));
 browser->startBrowse();
 \endcode
 
