@@ -20,14 +20,14 @@ Win::Win()
     KParts::Part* p =  factory->create( this, "tralala", "TQObject", "KParts::ReadOnlyPart" ) ;
     setCentralWidget( p->widget() );
 
-    TerminalInterface* t = ::tqqt_cast<TerminalInterface*>( p );
+    TerminalInterface* t = ::tqt_cast<TerminalInterface*>( p );
     t->showShellInDir( TQDir::home().path() );
 //     TQStrList l;
 //     l.append( "python" );
 //     t->startProgram( TQString::fromUtf8( "/usr/bin/python" ), l );
 
-    connect( p, TQT_SIGNAL( processExited( int ) ),
-             this, TQT_SLOT( pythonExited( int ) ) );
+    connect( p, TQ_SIGNAL( processExited( int ) ),
+             this, TQ_SLOT( pythonExited( int ) ) );
 }
 
 
@@ -46,11 +46,11 @@ int main( int argc, char** argv )
 void Win::pythonExited()
 {
     std::cerr << "hee, " << p << std::endl;
-    std::cerr << ( ::tqqt_cast<TerminalInterface>(p) ) << std::endl;
+    std::cerr << ( ::tqt_cast<TerminalInterface>(p) ) << std::endl;
     // KMessageBox::sorry( this, TQString::fromUtf8( "Exited, status was %1" ).arg( status ) );
-    disconnect(p, TQT_SIGNAL( processExited() ),
-            this, TQT_SLOT( pythonExited() ));
-    TerminalInterface* t = ::tqqt_cast<TerminalInterface*>( p );
+    disconnect(p, TQ_SIGNAL( processExited() ),
+            this, TQ_SLOT( pythonExited() ));
+    TerminalInterface* t = ::tqt_cast<TerminalInterface*>( p );
     TQStrList l;
     l.append( "echo" );
     l.append( "hello world" );
