@@ -5,7 +5,7 @@
 class Win
     : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
     KParts::Part* p;
 public:
     Win();
