@@ -2221,7 +2221,7 @@ QConfigDB::watch(bool state)
       if(timer==0)
 	{
 	  timer=new TQTimer(this);
-	  connect(timer, TQT_SIGNAL(timeout()), TQT_SLOT(checkFileChanged()));
+	  connect(timer, TQ_SIGNAL(timeout()), TQ_SLOT(checkFileChanged()));
 	}
       timer->start(1000);
     } else { // stop timer
