@@ -110,7 +110,7 @@ bool KateCommands::CoreCommands::exec(Kate::View *view,
   }
   else if ( cmd == "run-myself" )
   {
-#ifndef Q_WS_WIN //todo
+#ifndef TQ_WS_WIN //todo
     return KateFactory::self()->jscript()->execute(v, v->doc()->text(), errorMsg);
 #else
     return 0;
