@@ -58,7 +58,7 @@ KateSearch::KateSearch( KateView* view )
   m_arbitraryHLList = new KateSuperRangeList();
   if (arbitraryHLExample) m_doc->arbitraryHL()->addHighlightToView(m_arbitraryHLList, m_view);
 
-  connect(replacePrompt,TQT_SIGNAL(clicked()),this,TQT_SLOT(replaceSlot()));
+  connect(replacePrompt,TQ_SIGNAL(clicked()),this,TQ_SLOT(replaceSlot()));
 }
 
 KateSearch::~KateSearch()
@@ -68,13 +68,13 @@ KateSearch::~KateSearch()
 
 void KateSearch::createActions( TDEActionCollection* ac )
 {
-  KStdAction::find( this, TQT_SLOT(find()), ac )->setWhatsThis(
+  KStdAction::find( this, TQ_SLOT(find()), ac )->setWhatsThis(
     i18n("Look up the first occurrence of a piece of text or regular expression."));
-  KStdAction::findNext( this, TQT_SLOT(slotFindNext()), ac )->setWhatsThis(
+  KStdAction::findNext( this, TQ_SLOT(slotFindNext()), ac )->setWhatsThis(
     i18n("Look up the next occurrence of the search phrase."));
-  KStdAction::findPrev( this, TQT_SLOT(slotFindPrev()), ac, "edit_find_prev" )->setWhatsThis(
+  KStdAction::findPrev( this, TQ_SLOT(slotFindPrev()), ac, "edit_find_prev" )->setWhatsThis(
     i18n("Look up the previous occurrence of the search phrase."));
-  KStdAction::replace( this, TQT_SLOT(replace()), ac )->setWhatsThis(
+  KStdAction::replace( this, TQ_SLOT(replace()), ac )->setWhatsThis(
     i18n("Look up a piece of text or regular expression and replace the result with some given text."));
 }
 
@@ -729,10 +729,10 @@ bool KateSearch::doSearch( const TQString& text )
   if (arbitraryHLExample)  {
     KateArbitraryHighlightRange* hl = new KateArbitraryHighlightRange(new KateSuperCursor(m_doc, true, s.cursor), new KateSuperCursor(m_doc, true, s.cursor.line(), s.cursor.col() + s.matchedLength), this);
     hl->setBold();
-    hl->setTextColor(Qt::white);
-    hl->setBGColor(Qt::black);
+    hl->setTextColor(TQt::white);
+    hl->setBGColor(TQt::black);
     // destroy the highlight upon change
-    connect(hl, TQT_SIGNAL(contentsChanged()), hl, TQT_SIGNAL(eliminated()));
+    connect(hl, TQ_SIGNAL(contentsChanged()), hl, TQ_SIGNAL(eliminated()));
     m_arbitraryHLList->append(hl);
   }
 
