@@ -199,7 +199,7 @@ namespace {	// Private.
 } // namespace
 
 
-KDE_EXPORT void kimgio_hdr_read( TQImageIO * io )
+TDE_EXPORT void kimgio_hdr_read( TQImageIO * io )
 {
 	int len;
 	char line[MAXLINE];
@@ -258,7 +258,7 @@ KDE_EXPORT void kimgio_hdr_read( TQImageIO * io )
 }
 
 
-KDE_EXPORT void kimgio_hdr_write( TQImageIO * )
+TDE_EXPORT void kimgio_hdr_write( TQImageIO * )
 {
 	// intentionally not implemented (since writing low dynamic range data to a HDR file is nonsense.)
 }
