@@ -34,20 +34,10 @@
 #include "network.h"
 
 #include <tdeversion.h>
-#include <kdemacros.h>
-
-#if KDE_IS_VERSION( 3,3,90 )
-/* life is great */
-#else
-/* workaround typo that breaks compilation with newer gcc */
-#undef KDE_EXPORT
-#define KDE_EXPORT
-#undef KDE_NO_EXPORT
-#define KDE_NO_EXPORT
-#endif
+#include <tdemacros.h>
 
 extern "C" {
-	KDE_EXPORT KDEDModule* create_networkstatus( const TQCString& obj )
+	TDE_EXPORT KDEDModule* create_networkstatus( const TQCString& obj )
 	{
 		return new NetworkStatusModule( obj );
 	}
