@@ -711,15 +711,15 @@ bool AddressBook::addResource( Resource *resource )
   d->mManager->add( resource );
   resource->setAddressBook( this );
 
-  connect( resource, TQT_SIGNAL( loadingFinished( Resource* ) ),
-           this, TQT_SLOT( resourceLoadingFinished( Resource* ) ) );
-  connect( resource, TQT_SIGNAL( savingFinished( Resource* ) ),
-           this, TQT_SLOT( resourceSavingFinished( Resource* ) ) );
+  connect( resource, TQ_SIGNAL( loadingFinished( Resource* ) ),
+           this, TQ_SLOT( resourceLoadingFinished( Resource* ) ) );
+  connect( resource, TQ_SIGNAL( savingFinished( Resource* ) ),
+           this, TQ_SLOT( resourceSavingFinished( Resource* ) ) );
 
-  connect( resource, TQT_SIGNAL( loadingError( Resource*, const TQString& ) ),
-           this, TQT_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
-  connect( resource, TQT_SIGNAL( savingError( Resource*, const TQString& ) ),
-           this, TQT_SLOT( resourceSavingError( Resource*, const TQString& ) ) );
+  connect( resource, TQ_SIGNAL( loadingError( Resource*, const TQString& ) ),
+           this, TQ_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
+  connect( resource, TQ_SIGNAL( savingError( Resource*, const TQString& ) ),
+           this, TQ_SLOT( resourceSavingError( Resource*, const TQString& ) ) );
 
   return true;
 }
@@ -733,15 +733,15 @@ bool AddressBook::removeResource( Resource *resource )
 
   resource->setAddressBook( 0 );
 
-  disconnect( resource, TQT_SIGNAL( loadingFinished( Resource* ) ),
-              this, TQT_SLOT( resourceLoadingFinished( Resource* ) ) );
-  disconnect( resource, TQT_SIGNAL( savingFinished( Resource* ) ),
-              this, TQT_SLOT( resourceSavingFinished( Resource* ) ) );
+  disconnect( resource, TQ_SIGNAL( loadingFinished( Resource* ) ),
+              this, TQ_SLOT( resourceLoadingFinished( Resource* ) ) );
+  disconnect( resource, TQ_SIGNAL( savingFinished( Resource* ) ),
+              this, TQ_SLOT( resourceSavingFinished( Resource* ) ) );
 
-  disconnect( resource, TQT_SIGNAL( loadingError( Resource*, const TQString& ) ),
-              this, TQT_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
-  disconnect( resource, TQT_SIGNAL( savingError( Resource*, const TQString& ) ),
-              this, TQT_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
+  disconnect( resource, TQ_SIGNAL( loadingError( Resource*, const TQString& ) ),
+              this, TQ_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
+  disconnect( resource, TQ_SIGNAL( savingError( Resource*, const TQString& ) ),
+              this, TQ_SLOT( resourceLoadingError( Resource*, const TQString& ) ) );
 
   d->mManager->remove( resource );
 
