@@ -138,12 +138,12 @@ void LdapClient::startQuery( const TQString& filter )
   startParseLDIF();
   mActive = true;
   mJob = TDEIO::get( url, false, false );
-  connect( mJob, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
-           this, TQT_SLOT( slotData( TDEIO::Job*, const TQByteArray& ) ) );
-  connect( mJob, TQT_SIGNAL( infoMessage( TDEIO::Job*, const TQString& ) ),
-           this, TQT_SLOT( slotInfoMessage( TDEIO::Job*, const TQString& ) ) );
-  connect( mJob, TQT_SIGNAL( result( TDEIO::Job* ) ),
-           this, TQT_SLOT( slotDone() ) );
+  connect( mJob, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+           this, TQ_SLOT( slotData( TDEIO::Job*, const TQByteArray& ) ) );
+  connect( mJob, TQ_SIGNAL( infoMessage( TDEIO::Job*, const TQString& ) ),
+           this, TQ_SLOT( slotInfoMessage( TDEIO::Job*, const TQString& ) ) );
+  connect( mJob, TQ_SIGNAL( result( TDEIO::Job* ) ),
+           this, TQ_SLOT( slotDone() ) );
 }
 
 void LdapClient::cancelQuery()
@@ -285,18 +285,18 @@ LdapSearch::LdapSearch()
       attrs << "cn" << "mail" << "givenname" << "sn";
       ldapClient->setAttrs( attrs );
 
-      connect( ldapClient, TQT_SIGNAL( result( const TDEABC::LdapObject& ) ),
-               this, TQT_SLOT( slotLDAPResult( const TDEABC::LdapObject& ) ) );
-      connect( ldapClient, TQT_SIGNAL( done() ),
-               this, TQT_SLOT( slotLDAPDone() ) );
-      connect( ldapClient, TQT_SIGNAL( error( const TQString& ) ),
-               this, TQT_SLOT( slotLDAPError( const TQString& ) ) );
+      connect( ldapClient, TQ_SIGNAL( result( const TDEABC::LdapObject& ) ),
+               this, TQ_SLOT( slotLDAPResult( const TDEABC::LdapObject& ) ) );
+      connect( ldapClient, TQ_SIGNAL( done() ),
+               this, TQ_SLOT( slotLDAPDone() ) );
+      connect( ldapClient, TQ_SIGNAL( error( const TQString& ) ),
+               this, TQ_SLOT( slotLDAPError( const TQString& ) ) );
 
       mClients.append( ldapClient );
     }
   }
 
-  connect( &mDataTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotDataTimer() ) );
+  connect( &mDataTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotDataTimer() ) );
 }
 
 void LdapSearch::startSearch( const TQString& txt )
