@@ -51,7 +51,7 @@ int main(int argc,char **argv)
   editor->show();
   app.setMainWidget(editor);
   
-  TQObject::connect( &app, TQT_SIGNAL( lastWindowClosed() ), &app, TQT_SLOT( quit() ) );
+  TQObject::connect( &app, TQ_SIGNAL( lastWindowClosed() ), &app, TQ_SLOT( quit() ) );
 
   app.exec();
   
