@@ -201,7 +201,7 @@ KonfUpdate::log()
       }
    }
    
-   (*m_textStream) << TQDateTime::currentDateTime().toString( Qt::ISODate ) << " ";
+   (*m_textStream) << TQDateTime::currentDateTime().toString( TQt::ISODate ) << " ";
    
    return *m_textStream;
 }
@@ -938,7 +938,7 @@ void KonfUpdate::resetOptions()
 }
 
 
-extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
+extern "C" TDE_EXPORT int kdemain(int argc, char **argv)
 {
    TDEAboutData aboutData("tdeconf_update", I18N_NOOP("KConf Update"),
                         "1.0.2",
