@@ -45,7 +45,7 @@ class TDESocketAddressPrivate;
  */
 class TDECORE_EXPORT TDESocketAddress: public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 protected:
   /**
    * Creates an empty class
@@ -232,7 +232,7 @@ class KInetSocketAddressPrivate;
  */
 class TDECORE_EXPORT KInetSocketAddress: public ::TDESocketAddress
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   /**
    * Default constructor. Does nothing
@@ -583,7 +583,7 @@ class KUnixSocketAddressPrivate;
  */
 class TDECORE_EXPORT KUnixSocketAddress: public ::TDESocketAddress
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   /**
    * Default constructor
