@@ -41,7 +41,7 @@ namespace KNetwork
     class KSrvResolverWorker: public TQObject,
 			      public KNetwork::KResolverWorkerBase
     {
-      Q_OBJECT
+      TQ_OBJECT
       
 
     public:
