@@ -202,11 +202,7 @@ public:
 		TQWMatrix matrix = m_engine->painter()->parseTransform(transform);
 
 		TQWMatrix *current = m_engine->painter()->worldMatrix();
-#ifdef USE_QT4
-printf("[FIXME] *current = matrix * *current locks up under Qt4; bypassing for now\n");
-#else // USE_QT4
 		*current = matrix * *current;
-#endif // USE_QT4
 	}
 
 	void parseCommonAttributes(TQDomNode &node)
@@ -445,7 +441,7 @@ printf("[FIXME] *current = matrix * *current locks up under Qt4; bypassing for n
 			{
 				// Scale, if needed
 				if(image.width() != (int) w || image.height() != (int) h)
-					image = image.smoothScale((int) w, (int) h, TQ_ScaleFree);
+					image = image.smoothScale((int) w, (int) h, TQImage::ScaleFree);
 
 				m_engine->painter()->drawImage(x, y, image);
 			}
