@@ -161,7 +161,7 @@ void TDEConfigSkeleton::ItemBool::setProperty(const TQVariant & p)
 
 TQVariant TDEConfigSkeleton::ItemBool::property() const
 {
-  return TQVariant( mReference, 42 /* dummy */ );
+  return TQVariant( mReference );
 }
 
 
