@@ -30,7 +30,7 @@
 
 class TDECORE_EXPORT TDEGenericDevice : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	public:
 		/**
