@@ -22,16 +22,13 @@
 
 #include "tdegenericdevice.h"
 #include "tqvariant.h"
+#include "tdemacros.h"
 
 struct crypt_device;
 
 // Keep readDiskDeviceSubtypeFromString() in tdehardwaredevices.cpp in sync with this enum
 namespace TDEDiskDeviceType {
-#if __cplusplus >= 201103L
 enum TDEDiskDeviceType : unsigned long long {
-#else
-enum TDEDiskDeviceType {
-#endif
 	Null          = 0x0000000000000000ULL,
 	MediaDevice   = 0x0000000000000001ULL,
 	Floppy        = 0x0000000000000002ULL,
@@ -107,7 +104,7 @@ enum TDEDiskDeviceStatus {
 	UsedByDevice       = 0x00000010,
 	UsesDevice         = 0x00000020,
 	ContainsFilesystem = 0x00000040,
-	Hotpluggable       = 0x00000080,
+	Hotpluggable TDE_DEPRECATED = 0x00000080 , //< @deprecated; use Removable instead
 	Hidden             = 0x00000100,
 	Other              = 0x80000000
 };
