@@ -410,7 +410,7 @@ public:
    *
    * calls formatNumber(numStr, 2)
    */
-  TQString formatNumber(const TQString &numStr) const KDE_DEPRECATED;
+  TQString formatNumber(const TQString &numStr) const TDE_DEPRECATED;
 
   /**
    * Given a string representing a number, converts that to a numeric
@@ -512,7 +512,7 @@ public:
    *
    * @return true if the week starts on Monday
    */
-  bool weekStartsMonday() const KDE_DEPRECATED; //### remove for KDE 4.0
+  bool weekStartsMonday() const TDE_DEPRECATED; //### remove for KDE 4.0
 
   /**
    * Use this to determine which day is the first day of the week.
@@ -542,7 +542,7 @@ public:
    * \endcode
    * to the applicable file.
    */
-  TQString monthName(int i, bool shortName = false) const KDE_DEPRECATED;
+  TQString monthName(int i, bool shortName = false) const TDE_DEPRECATED;
 
   /**
    * @deprecated
@@ -567,7 +567,7 @@ public:
    * \endcode
    * to the applicable file.
   */
-  TQString monthNamePossessive(int i, bool shortName = false) const KDE_DEPRECATED;
+  TQString monthNamePossessive(int i, bool shortName = false) const TDE_DEPRECATED;
 
   /**
    * @deprecated use calendar()->weekDayName
@@ -579,7 +579,7 @@ public:
    *
    * @return The name of the day
    */
-  TQString weekDayName(int i, bool shortName = false) const KDE_DEPRECATED;
+  TQString weekDayName(int i, bool shortName = false) const TDE_DEPRECATED;
 
   /**
    * Returns a pointer to the calendar system object.
@@ -880,7 +880,7 @@ public:
    *
    * @param start True if Monday is the first day in the week
    */
-  void setWeekStartsMonday(bool start) KDE_DEPRECATED; //### remove for KDE 4.0
+  void setWeekStartsMonday(bool start) TDE_DEPRECATED; //### remove for KDE 4.0
 
   /**
    * Changes how TDELocale defines the first day in week.
@@ -1148,7 +1148,7 @@ private:
    * @deprecated
    * use formatMoney(double)
    */
-  TQString formatMoney(const TQString &numStr) const KDE_DEPRECATED;
+  TQString formatMoney(const TQString &numStr) const TDE_DEPRECATED;
 
   /**
    * @deprecated
@@ -1156,19 +1156,19 @@ private:
    *
    * @return String containing language codes separated by colons
    */
-  TQString languages() const KDE_DEPRECATED;
+  TQString languages() const TDE_DEPRECATED;
 
   /**
    * @deprecated
    * @return True
    */
-  bool setCharset(const TQString & charset) KDE_DEPRECATED;
+  bool setCharset(const TQString & charset) TDE_DEPRECATED;
 
   /**
    * @deprecated
    * @see encoding
    */
-  TQString charset() const KDE_DEPRECATED;
+  TQString charset() const TDE_DEPRECATED;
 
 protected:
   /**
@@ -1220,22 +1220,12 @@ private:
   /**
    * @internal A TQFile filename encoding function (TQFile::encodeFn).
    */
-#ifdef USE_QT3
   static TQCString encodeFileNameUTF8( const TQString & fileName );
-#endif // USE_QT3
-#ifdef USE_QT4
-  static QByteArray encodeFileNameUTF8( const QString & fileName );
-#endif // USE_QT4
 
   /**
    * @internal TQFile filename decoding function (TQFile::decodeFn).
    */
-#ifdef USE_QT3
   static TQString decodeFileNameUTF8( const TQCString & localFileName );
-#endif // USE_QT3
-#ifdef USE_QT4
-  static QString decodeFileNameUTF8( const QByteArray & localFileName );
-#endif // USE_QT4
 
   /**
    * @internal Changes the file name of the catalog to the correct
