@@ -32,7 +32,7 @@ werke\nmerkt\nich\nund\nden\nbrauch\nund\nmit\ngeistesstaerke\ntu\nich\nwunder\n
 int main(int argc, char *argv[])
 {
  Dummy dummy; 
- TDEApplication app(argc, argv, "kprociotest");
+ TDEApplication app(argc, argv, TQCString("kprociotest"));
 
  printf("Welcome to the KProcIO Demo Application!\n");
 
@@ -41,8 +41,8 @@ int main(int argc, char *argv[])
  
  p << "rev";
  
- p.connect(&p, TQT_SIGNAL(processExited(TDEProcess*)), &dummy, TQT_SLOT(printMessage(TDEProcess*)));
- p.connect(&p, TQT_SIGNAL(readReady(KProcIO*)), &dummy, TQT_SLOT(gotOutput(KProcIO*)));
+ p.connect(&p, TQ_SIGNAL(processExited(TDEProcess*)), &dummy, TQ_SLOT(printMessage(TDEProcess*)));
+ p.connect(&p, TQ_SIGNAL(readReady(KProcIO*)), &dummy, TQ_SLOT(gotOutput(KProcIO*)));
 
  bool b;
 
