@@ -78,13 +78,13 @@ HTMLDocumentImpl::HTMLDocumentImpl(DOMImplementationImpl *_implementation, TDEHT
     m_doAutoFill = false;
 
 /* dynamic history stuff to be fixed later (pfeiffer)
-    connect( TDEHTMLFactory::vLinks(), TQT_SIGNAL( removed( const TQString& )),
-             TQT_SLOT( slotHistoryChanged() ));
+    connect( TDEHTMLFactory::vLinks(), TQ_SIGNAL( removed( const TQString& )),
+             TQ_SLOT( slotHistoryChanged() ));
 */
-    connect( TDEHTMLFactory::vLinks(), TQT_SIGNAL( inserted( const TQString& ) ),
-             TQT_SLOT( slotHistoryChanged() ));
-    connect( TDEHTMLFactory::vLinks(), TQT_SIGNAL( cleared()),
-             TQT_SLOT( slotHistoryChanged() ));
+    connect( TDEHTMLFactory::vLinks(), TQ_SIGNAL( inserted( const TQString& ) ),
+             TQ_SLOT( slotHistoryChanged() ));
+    connect( TDEHTMLFactory::vLinks(), TQ_SIGNAL( cleared()),
+             TQ_SLOT( slotHistoryChanged() ));
 }
 
 HTMLDocumentImpl::~HTMLDocumentImpl()
