@@ -66,7 +66,7 @@ RenderFrameSet::RenderFrameSet( HTMLFrameSetElementImpl *frameSet)
 
   m_resizing = m_clientresizing= false;
 
-  m_cursor = Qt::ArrowCursor;
+  m_cursor = TQt::ArrowCursor;
 
   m_hSplit = -1;
   m_vSplit = -1;
@@ -498,13 +498,13 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
   }
 
 
-  m_cursor = Qt::ArrowCursor;
+  m_cursor = TQt::ArrowCursor;
   if(m_hSplit != -1 && m_vSplit != -1)
-      m_cursor = Qt::SizeAllCursor;
+      m_cursor = TQt::SizeAllCursor;
   else if( m_vSplit != -1 )
-      m_cursor = Qt::SizeHorCursor;
+      m_cursor = TQt::SizeHorCursor;
   else if( m_hSplit != -1 )
-      m_cursor = Qt::SizeVerCursor;
+      m_cursor = TQt::SizeVerCursor;
 
   if(!m_resizing && evt->id() == EventImpl::MOUSEDOWN_EVENT)
   {
@@ -548,8 +548,8 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
   TDEHTMLView *view = canvas()->view();
   if ((m_resizing || evt->id() == EventImpl::MOUSEUP_EVENT) && view) {
       TQPainter paint( view );
-      paint.setPen( Qt::gray );
-      paint.setBrush( Qt::gray );
+      paint.setPen( TQt::gray );
+      paint.setBrush( TQt::gray );
       paint.setRasterOp( TQt::XorROP );
       TQRect r(xPos(), yPos(), width(), height());
       const int rBord = 3;
@@ -636,7 +636,7 @@ void RenderPart::setWidget( TQWidget *widget )
     setQWidget( widget );
     widget->setFocusPolicy(TQWidget::WheelFocus);
     if(widget->inherits("TDEHTMLView"))
-        connect( widget, TQT_SIGNAL( cleared() ), this, TQT_SLOT( slotViewCleared() ) );
+        connect( widget, TQ_SIGNAL( cleared() ), this, TQ_SLOT( slotViewCleared() ) );
 
     setNeedsLayoutAndMinMaxRecalc();
 
@@ -888,7 +888,7 @@ bool RenderPartObject::partLoadingErrorNotify( tdehtml::ChildFrame *childFrame,
     }
     // Dissociate ourselves from the current event loop (to prevent crashes
     // due to the message box staying up)
-    TQTimer::singleShot( 0, this, TQT_SLOT( slotPartLoadingErrorNotify() ) );
+    TQTimer::singleShot( 0, this, TQ_SLOT( slotPartLoadingErrorNotify() ) );
 #if 0
     Tokenizer *tokenizer = static_cast<DOM::DocumentImpl *>(part->document().handle())->tokenizer();
     if (tokenizer) tokenizer->setOnHold( true );
