@@ -36,7 +36,7 @@ namespace DOM
   class DocumentImpl;
 }
 
-class KDE_EXPORT TDEHTMLFactory : public KParts::Factory
+class TDE_EXPORT TDEHTMLFactory : public KParts::Factory
 {
   TQ_OBJECT
   friend class DOM::DocumentImpl;
