@@ -115,7 +115,7 @@ KMultiPart::KMultiPart( TQWidget *parentWidget, const char *widgetName,
     m_tempFile = 0L;
 
     m_timer = new TQTimer( this );
-    connect( m_timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotProgressInfo() ) );
+    connect( m_timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotProgressInfo() ) );
 }
 
 KMultiPart::~KMultiPart()
@@ -167,10 +167,10 @@ bool KMultiPart::openURL( const KURL &url )
 
     emit started( 0 /*m_job*/ ); // don't pass the job, it would interfer with our own infoMessage
 
-    connect( m_job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-             this, TQT_SLOT( slotJobFinished( TDEIO::Job * ) ) );
-    connect( m_job, TQT_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ),
-             this, TQT_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
+    connect( m_job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+             this, TQ_SLOT( slotJobFinished( TDEIO::Job * ) ) );
+    connect( m_job, TQ_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ),
+             this, TQ_SLOT( slotData( TDEIO::Job *, const TQByteArray & ) ) );
 
     m_numberOfFrames = 0;
     m_numberOfFramesSkipped = 0;
@@ -324,8 +324,8 @@ void KMultiPart::setPart( const TQString& mimeType )
     insertChildClient( m_part );
     m_part->widget()->show();
 
-    connect( m_part, TQT_SIGNAL( completed() ),
-             this, TQT_SLOT( slotPartCompleted() ) );
+    connect( m_part, TQ_SIGNAL( completed() ),
+             this, TQ_SLOT( slotPartCompleted() ) );
 
     m_isHTMLPart = ( mimeType == "text/html" );
     KParts::BrowserExtension* childExtension = KParts::BrowserExtension::childObject( m_part );
@@ -336,62 +336,62 @@ void KMultiPart::setPart( const TQString& mimeType )
         // Forward signals from the part's browser extension
         // this is very related (but not exactly like) TDEHTMLPart::processObjectRequest
 
-        connect( childExtension, TQT_SIGNAL( openURLNotify() ),
-                 m_extension, TQT_SIGNAL( openURLNotify() ) );
+        connect( childExtension, TQ_SIGNAL( openURLNotify() ),
+                 m_extension, TQ_SIGNAL( openURLNotify() ) );
 
-        connect( childExtension, TQT_SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
-                 m_extension, TQT_SIGNAL( openURLRequest( const KURL &, const KParts::URLArgs & ) ) );
+        connect( childExtension, TQ_SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
+                 m_extension, TQ_SIGNAL( openURLRequest( const KURL &, const KParts::URLArgs & ) ) );
 
-        connect( childExtension, TQT_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & ) ),
-                 m_extension, TQT_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & ) ) );
-        connect( childExtension, TQT_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs &, const KParts::WindowArgs &, KParts::ReadOnlyPart *& ) ),
-                 m_extension, TQT_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & , const KParts::WindowArgs &, KParts::ReadOnlyPart *&) ) );
+        connect( childExtension, TQ_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & ) ),
+                 m_extension, TQ_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & ) ) );
+        connect( childExtension, TQ_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs &, const KParts::WindowArgs &, KParts::ReadOnlyPart *& ) ),
+                 m_extension, TQ_SIGNAL( createNewWindow( const KURL &, const KParts::URLArgs & , const KParts::WindowArgs &, KParts::ReadOnlyPart *&) ) );
 
         // Keep in sync with tdehtml_part.cpp
-        connect( childExtension, TQT_SIGNAL( popupMenu( const TQPoint &, const KFileItemList & ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( const TQPoint &, const KFileItemList & ) ) );
-        connect( childExtension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList & ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList & ) ) );
-        connect( childExtension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ) );
-        connect( childExtension, TQT_SIGNAL( popupMenu( const TQPoint &, const KURL &, const TQString &, mode_t ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( const TQPoint &, const KURL &, const TQString &, mode_t ) ) );
-        connect( childExtension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const TQString &, mode_t ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const TQString &, mode_t ) ) );
-        connect( childExtension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ),
-                 m_extension, TQT_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( const TQPoint &, const KFileItemList & ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( const TQPoint &, const KFileItemList & ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList & ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList & ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KFileItemList &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( const TQPoint &, const KURL &, const TQString &, mode_t ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( const TQPoint &, const KURL &, const TQString &, mode_t ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const TQString &, mode_t ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const TQString &, mode_t ) ) );
+        connect( childExtension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ),
+                 m_extension, TQ_SIGNAL( popupMenu( KXMLGUIClient *, const TQPoint &, const KURL &, const KParts::URLArgs &, KParts::BrowserExtension::PopupFlags, mode_t ) ) );
 
 
         if ( m_isHTMLPart )
-            connect( childExtension, TQT_SIGNAL( infoMessage( const TQString & ) ),
-                     m_extension, TQT_SIGNAL( infoMessage( const TQString & ) ) );
+            connect( childExtension, TQ_SIGNAL( infoMessage( const TQString & ) ),
+                     m_extension, TQ_SIGNAL( infoMessage( const TQString & ) ) );
         // For non-HTML we prefer to show our infoMessage ourselves.
 
         childExtension->setBrowserInterface( m_extension->browserInterface() );
 
-        connect( childExtension, TQT_SIGNAL( enableAction( const char *, bool ) ),
-                 m_extension, TQT_SIGNAL( enableAction( const char *, bool ) ) );
-        connect( childExtension, TQT_SIGNAL( setLocationBarURL( const TQString& ) ),
-                 m_extension, TQT_SIGNAL( setLocationBarURL( const TQString& ) ) );
-        connect( childExtension, TQT_SIGNAL( setIconURL( const KURL& ) ),
-                 m_extension, TQT_SIGNAL( setIconURL( const KURL& ) ) );
-        connect( childExtension, TQT_SIGNAL( loadingProgress( int ) ),
-                 m_extension, TQT_SIGNAL( loadingProgress( int ) ) );
+        connect( childExtension, TQ_SIGNAL( enableAction( const char *, bool ) ),
+                 m_extension, TQ_SIGNAL( enableAction( const char *, bool ) ) );
+        connect( childExtension, TQ_SIGNAL( setLocationBarURL( const TQString& ) ),
+                 m_extension, TQ_SIGNAL( setLocationBarURL( const TQString& ) ) );
+        connect( childExtension, TQ_SIGNAL( setIconURL( const KURL& ) ),
+                 m_extension, TQ_SIGNAL( setIconURL( const KURL& ) ) );
+        connect( childExtension, TQ_SIGNAL( loadingProgress( int ) ),
+                 m_extension, TQ_SIGNAL( loadingProgress( int ) ) );
         if ( m_isHTMLPart ) // for non-HTML we have our own
-            connect( childExtension, TQT_SIGNAL( speedProgress( int ) ),
-                     m_extension, TQT_SIGNAL( speedProgress( int ) ) );
-        connect( childExtension, TQT_SIGNAL( selectionInfo( const KFileItemList& ) ),
-                 m_extension, TQT_SIGNAL( selectionInfo( const KFileItemList& ) ) );
-        connect( childExtension, TQT_SIGNAL( selectionInfo( const TQString& ) ),
-                 m_extension, TQT_SIGNAL( selectionInfo( const TQString& ) ) );
-        connect( childExtension, TQT_SIGNAL( selectionInfo( const KURL::List& ) ),
-                 m_extension, TQT_SIGNAL( selectionInfo( const KURL::List& ) ) );
-        connect( childExtension, TQT_SIGNAL( mouseOverInfo( const KFileItem* ) ),
-                 m_extension, TQT_SIGNAL( mouseOverInfo( const KFileItem* ) ) );
-        connect( childExtension, TQT_SIGNAL( moveTopLevelWidget( int, int ) ),
-                 m_extension, TQT_SIGNAL( moveTopLevelWidget( int, int ) ) );
-        connect( childExtension, TQT_SIGNAL( resizeTopLevelWidget( int, int ) ),
-                 m_extension, TQT_SIGNAL( resizeTopLevelWidget( int, int ) ) );
+            connect( childExtension, TQ_SIGNAL( speedProgress( int ) ),
+                     m_extension, TQ_SIGNAL( speedProgress( int ) ) );
+        connect( childExtension, TQ_SIGNAL( selectionInfo( const KFileItemList& ) ),
+                 m_extension, TQ_SIGNAL( selectionInfo( const KFileItemList& ) ) );
+        connect( childExtension, TQ_SIGNAL( selectionInfo( const TQString& ) ),
+                 m_extension, TQ_SIGNAL( selectionInfo( const TQString& ) ) );
+        connect( childExtension, TQ_SIGNAL( selectionInfo( const KURL::List& ) ),
+                 m_extension, TQ_SIGNAL( selectionInfo( const KURL::List& ) ) );
+        connect( childExtension, TQ_SIGNAL( mouseOverInfo( const KFileItem* ) ),
+                 m_extension, TQ_SIGNAL( mouseOverInfo( const KFileItem* ) ) );
+        connect( childExtension, TQ_SIGNAL( moveTopLevelWidget( int, int ) ),
+                 m_extension, TQ_SIGNAL( moveTopLevelWidget( int, int ) ) );
+        connect( childExtension, TQ_SIGNAL( resizeTopLevelWidget( int, int ) ),
+                 m_extension, TQ_SIGNAL( resizeTopLevelWidget( int, int ) ) );
     }
 
     m_partIsLoading = false;
@@ -414,7 +414,7 @@ void KMultiPart::startOfData()
     if ( m_gzip )
     {
         m_filter = new HTTPFilterGZip;
-        connect( m_filter, TQT_SIGNAL( output( const TQByteArray& ) ), this, TQT_SLOT( reallySendData( const TQByteArray& ) ) );
+        connect( m_filter, TQ_SIGNAL( output( const TQByteArray& ) ), this, TQ_SLOT( reallySendData( const TQByteArray& ) ) );
     }
 
     if ( m_mimeType != m_nextMimeType )
@@ -551,7 +551,7 @@ void KMultiPart::slotJobFinished( TDEIO::Job *job )
 
         emit completed();
 
-        //TQTimer::singleShot( 0, this, TQT_SLOT( updateWindowCaption() ) );
+        //TQTimer::singleShot( 0, this, TQ_SLOT( updateWindowCaption() ) );
     }
     m_job = 0L;
 }
