@@ -39,7 +39,7 @@ class TQPopupMenu;
  */
 class TDEIO_EXPORT KBookmarkBar : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     
     friend class RMB;
 public:
