@@ -37,13 +37,13 @@
 #include <tdewallet.h>
 
 #include "config.h"
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #endif
 
 extern "C" {
-    KDE_EXPORT KDEDModule *create_kpasswdserver(const TQCString &name)
+    TDE_EXPORT KDEDModule *create_kpasswdserver(const TQCString &name)
     {
        return new KPasswdServer(name);
     }
@@ -76,8 +76,8 @@ KPasswdServer::KPasswdServer(const TQCString &name)
     m_authPending.setAutoDelete(true);
     m_seqNr = 0;
     m_wallet = 0;
-    connect(this, TQT_SIGNAL(windowUnregistered(long)),
-            this, TQT_SLOT(removeAuthForWindowId(long)));
+    connect(this, TQ_SIGNAL(windowUnregistered(long)),
+            this, TQ_SLOT(removeAuthForWindowId(long)));
 }
 
 KPasswdServer::~KPasswdServer()
@@ -279,7 +279,7 @@ KPasswdServer::queryAuthInfo(TDEIO::AuthInfo info, TQString errorMsg, long windo
     m_authPending.append(request);
 
     if (m_authPending.count() == 1)
-       TQTimer::singleShot(0, this, TQT_SLOT(processRequest()));
+       TQTimer::singleShot(0, this, TQ_SLOT(processRequest()));
 
     return info;
 }
@@ -386,7 +386,7 @@ KPasswdServer::processRequest()
             if (hasWalletData)
                 dlg.setKeepPassword( true );
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
             XSetTransientForHint( tqt_xdisplay(), dlg.winId(), request->windowId);
 #endif
 
@@ -493,7 +493,7 @@ KPasswdServer::processRequest()
     }
 
     if (m_authPending.count())
-       TQTimer::singleShot(0, this, TQT_SLOT(processRequest()));
+       TQTimer::singleShot(0, this, TQ_SLOT(processRequest()));
 
 }
 
