@@ -1063,15 +1063,15 @@ public:
 #  undef X509_STORE_CTX_set_chain
 #  undef SSLv23_client_method
 #endif
-   STACK *sk_dup(const STACK *s) KDE_DEPRECATED;
-   void sk_free(STACK *s) KDE_DEPRECATED;
-   STACK *sk_new(int (*cmp)()) KDE_DEPRECATED;
-   int sk_num(STACK *s) KDE_DEPRECATED;
-   char *sk_pop(STACK *s) KDE_DEPRECATED;
-   int sk_push(STACK *s, char *d) KDE_DEPRECATED;
-   char *sk_value(STACK *s, int n) KDE_DEPRECATED;
-   void X509_STORE_CTX_set_chain(X509_STORE_CTX *v, STACK_OF(X509)* x) KDE_DEPRECATED;
-   SSL_METHOD *SSLv23_client_method() KDE_DEPRECATED;
+   STACK *sk_dup(const STACK *s) TDE_DEPRECATED;
+   void sk_free(STACK *s) TDE_DEPRECATED;
+   STACK *sk_new(int (*cmp)()) TDE_DEPRECATED;
+   int sk_num(STACK *s) TDE_DEPRECATED;
+   char *sk_pop(STACK *s) TDE_DEPRECATED;
+   int sk_push(STACK *s, char *d) TDE_DEPRECATED;
+   char *sk_value(STACK *s, int n) TDE_DEPRECATED;
+   void X509_STORE_CTX_set_chain(X509_STORE_CTX *v, STACK_OF(X509)* x) TDE_DEPRECATED;
+   SSL_METHOD *SSLv23_client_method() TDE_DEPRECATED;
 
 #endif
 
