@@ -20,9 +20,9 @@
 #ifndef _INCLUDE_KSSLUTILS_H
 #define _INCLUDE_KSSLUTILS_H
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 #include "ksslconfig_win.h"
 #else
 #include "ksslconfig.h"
@@ -48,7 +48,7 @@ class TQDateTime;
  *  @return the date formatted in a TQString
  *  @see ASN1_UTCTIME_QDateTime
  */
-KDE_EXPORT TQString ASN1_UTCTIME_QString(ASN1_UTCTIME *tm);
+TDE_EXPORT TQString ASN1_UTCTIME_QString(ASN1_UTCTIME *tm);
 
 /**
  *  Convert an ASN1 UTCTIME value to a TQDateTime.  Uses TDELocale settings.
@@ -58,7 +58,7 @@ KDE_EXPORT TQString ASN1_UTCTIME_QString(ASN1_UTCTIME *tm);
  *
  *  @return the date formatted in a QDateTime
  */
-KDE_EXPORT TQDateTime ASN1_UTCTIME_QDateTime(ASN1_UTCTIME *tm, int *isGmt);
+TDE_EXPORT TQDateTime ASN1_UTCTIME_QDateTime(ASN1_UTCTIME *tm, int *isGmt);
 
 
 /**
@@ -68,7 +68,7 @@ KDE_EXPORT TQDateTime ASN1_UTCTIME_QDateTime(ASN1_UTCTIME *tm, int *isGmt);
  *
  *  @return the number formatted in a TQString
  */
-KDE_EXPORT TQString ASN1_INTEGER_QString(ASN1_INTEGER *aint);
+TDE_EXPORT TQString ASN1_INTEGER_QString(ASN1_INTEGER *aint);
 #endif
 
 
