@@ -51,7 +51,7 @@
 #include <assert.h>
 
 extern "C" {
-   KDE_EXPORT KDEDModule *create_tdewalletd(const TQCString &name) {
+   TDE_EXPORT KDEDModule *create_tdewalletd(const TQCString &name) {
 	   return new TDEWalletD(name);
    }
 }
@@ -92,17 +92,17 @@ TDEWalletD::TDEWalletD(const TQCString &name)
 	_timeouts = new KTimeout(17);
 	_closeIdle = false;
 	_idleTime = 0;
-	connect(_timeouts, TQT_SIGNAL(timedOut(int)), this, TQT_SLOT(timedOut(int)));
+	connect(_timeouts, TQ_SIGNAL(timedOut(int)), this, TQ_SLOT(timedOut(int)));
 	reconfigure();
 	TDEGlobal::dirs()->addResourceType("tdewallet", "share/apps/tdewallet");
 	connect(TDEApplication::dcopClient(),
-		TQT_SIGNAL(applicationRemoved(const TQCString&)),
+		TQ_SIGNAL(applicationRemoved(const TQCString&)),
 		this,
-		TQT_SLOT(slotAppUnregistered(const TQCString&)));
+		TQ_SLOT(slotAppUnregistered(const TQCString&)));
 	_dw = new KDirWatch(this, "TDEWallet Directory Watcher");
 	_dw->addDir(TDEGlobal::dirs()->saveLocation("tdewallet"));
 	_dw->startScan(true);
-	connect(_dw, TQT_SIGNAL(dirty(const TQString&)), this, TQT_SLOT(emitWalletListDirty()));
+	connect(_dw, TQ_SIGNAL(dirty(const TQString&)), this, TQ_SLOT(emitWalletListDirty()));
 }
 
 
@@ -229,7 +229,7 @@ void TDEWalletD::openAsynchronous(const TQString& wallet, const TQCString& retur
 
 	DCOPRef(appid, returnObject).send("walletOpenResult", 0);
 
-	TQTimer::singleShot(0, this, TQT_SLOT(processTransactions()));
+	TQTimer::singleShot(0, this, TQ_SLOT(processTransactions()));
 	checkActiveDialog();
 }
 
@@ -266,7 +266,7 @@ int TDEWalletD::open(const TQString& wallet, uint wId) {
 	xact->wId = wId;
 	xact->tType = TDEWalletTransaction::Open;
 	xact->modal = true; // mark dialogs as modal, the app has blocking wait
-	TQTimer::singleShot(0, this, TQT_SLOT(processTransactions()));
+	TQTimer::singleShot(0, this, TQ_SLOT(processTransactions()));
 	checkActiveDialog();
 	return 0; // process later
 }
@@ -386,7 +386,7 @@ int TDEWalletD::tryOpen(const TQString& wallet, const TQCString& password)
         _tryOpenBlocked.start (30 * 1000, true /*single shot*/);
         if (++_failed > 5) {
             _failed = 0;
-            TQTimer::singleShot(0, this, TQT_SLOT(notifyFailures()));
+            TQTimer::singleShot(0, this, TQ_SLOT(notifyFailures()));
         }
 
         rc = -1;
@@ -627,7 +627,7 @@ void TDEWalletD::changePassword(const TQString& wallet, uint wId) {
 
 	_transactions.append(xact);
 
-	TQTimer::singleShot(0, this, TQT_SLOT(processTransactions()));
+	TQTimer::singleShot(0, this, TQ_SLOT(processTransactions()));
 	checkActiveDialog();
 }
 
@@ -801,7 +801,7 @@ bool TDEWalletD::isOpen(int handle) {
 
 	if (rc == 0 && ++_failed > 5) {
 		_failed = 0;
-		TQTimer::singleShot(0, this, TQT_SLOT(notifyFailures()));
+		TQTimer::singleShot(0, this, TQ_SLOT(notifyFailures()));
 	} else if (rc != 0) {
 		_failed = 0;
 	}
@@ -1229,7 +1229,7 @@ TDEWallet::Backend *TDEWalletD::getWallet(const TQCString& appid, int handle) {
 
 	if (++_failed > 5) {
 		_failed = 0;
-		TQTimer::singleShot(0, this, TQT_SLOT(notifyFailures()));
+		TQTimer::singleShot(0, this, TQ_SLOT(notifyFailures()));
 	}
 
 	return 0L;
