@@ -94,11 +94,11 @@ class UIServerSystemTray:public KSystemTray
          :KSystemTray(uis)
       {
          TDEPopupMenu* pop= contextMenu();
-         pop->insertItem(i18n("Settings..."), uis, TQT_SLOT(slotConfigure()));
-         pop->insertItem(i18n("Remove"), uis, TQT_SLOT(slotRemoveSystemTrayIcon()));
+         pop->insertItem(i18n("Settings..."), uis, TQ_SLOT(slotConfigure()));
+         pop->insertItem(i18n("Remove"), uis, TQ_SLOT(slotRemoveSystemTrayIcon()));
          setPixmap(loadIcon("document-save"));
          //actionCollection()->action("file_quit")->setEnabled(true);
-         KStdAction::quit(TQT_TQOBJECT(uis), TQT_SLOT(slotQuit()), actionCollection());
+         KStdAction::quit(uis, TQ_SLOT(slotQuit()), actionCollection());
       }
 };
 
@@ -193,8 +193,8 @@ ProgressItem::ProgressItem( ListProgress* view, TQListViewItem *after, TQCString
   // create dialog, but don't show it
   defaultProgress = new TDEIO::DefaultProgress( false );
   defaultProgress->setOnlyClean( true );
-  connect ( defaultProgress, TQT_SIGNAL( stopped() ), this, TQT_SLOT( slotCanceled() ) );
-  connect ( &m_showTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT(slotShowDefaultProgress()) );
+  connect ( defaultProgress, TQ_SIGNAL( stopped() ), this, TQ_SLOT( slotCanceled() ) );
+  connect ( &m_showTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT(slotShowDefaultProgress()) );
 
   if ( showDefault ) {
     m_showTimer.start( 500, true );
@@ -478,7 +478,7 @@ ListProgress::ListProgress (TQWidget *parent, const char *name)
   //used for squeezing the text in local file name and url
   m_squeezer=new KSqueezedTextLabel(this);
   m_squeezer->hide();
-  connect(header(),TQT_SIGNAL(sizeChange(int,int,int)),this,TQT_SLOT(columnWidthChanged(int)));
+  connect(header(),TQ_SIGNAL(sizeChange(int,int,int)),this,TQ_SLOT(columnWidthChanged(int)));
 }
 
 
@@ -595,11 +595,11 @@ UIServer::UIServer()
 
   // setup toolbar
   toolBar()->insertButton("edit-delete", TOOL_CANCEL,
-                          TQT_SIGNAL(clicked()), TQT_TQOBJECT(this),
-                          TQT_SLOT(slotCancelCurrent()), FALSE, i18n("Cancel"));
+                          TQ_SIGNAL(clicked()), this,
+                          TQ_SLOT(slotCancelCurrent()), FALSE, i18n("Cancel"));
   toolBar()->insertButton("configure", TOOL_CONFIGURE,
-                          TQT_SIGNAL(clicked()), TQT_TQOBJECT(this),
-                          TQT_SLOT(slotConfigure()), true, i18n("Settings..."));
+                          TQ_SIGNAL(clicked()), this,
+                          TQ_SLOT(slotConfigure()), true, i18n("Settings..."));
 
   toolBar()->setBarPos( TDEToolBar::Left );
 
@@ -614,18 +614,18 @@ UIServer::UIServer()
 
   setCentralWidget( listProgress );
 
-  connect( listProgress, TQT_SIGNAL( selectionChanged() ),
-           TQT_SLOT( slotSelection() ) );
-  connect( listProgress, TQT_SIGNAL( executed( TQListViewItem* ) ),
-           TQT_SLOT( slotToggleDefaultProgress( TQListViewItem* ) ) );
-  connect( listProgress, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem *, const TQPoint &)),
-           TQT_SLOT(slotShowContextMenu(TDEListView*, TQListViewItem *, const TQPoint&)));
+  connect( listProgress, TQ_SIGNAL( selectionChanged() ),
+           TQ_SLOT( slotSelection() ) );
+  connect( listProgress, TQ_SIGNAL( executed( TQListViewItem* ) ),
+           TQ_SLOT( slotToggleDefaultProgress( TQListViewItem* ) ) );
+  connect( listProgress, TQ_SIGNAL( contextMenu( TDEListView*, TQListViewItem *, const TQPoint &)),
+           TQ_SLOT(slotShowContextMenu(TDEListView*, TQListViewItem *, const TQPoint&)));
 
 
   // setup animation timer
   updateTimer = new TQTimer( this );
-  connect( updateTimer, TQT_SIGNAL( timeout() ),
-           TQT_SLOT( slotUpdate() ) );
+  connect( updateTimer, TQ_SIGNAL( timeout() ),
+           TQ_SLOT( slotUpdate() ) );
   m_bUpdateNewJob=false;
 
   setCaption(i18n("Progress Dialog"));
@@ -675,10 +675,10 @@ void UIServer::slotShowContextMenu(TDEListView*, TQListViewItem* item, const TQP
    if (m_contextMenu==0)
    {
       m_contextMenu=new TQPopupMenu(this);
-      m_idCancelItem = m_contextMenu->insertItem(i18n("Cancel Job"), this, TQT_SLOT(slotCancelCurrent()));
-//      m_contextMenu->insertItem(i18n("Toggle Progress"), this, TQT_SLOT(slotToggleDefaultProgress()));
+      m_idCancelItem = m_contextMenu->insertItem(i18n("Cancel Job"), this, TQ_SLOT(slotCancelCurrent()));
+//      m_contextMenu->insertItem(i18n("Toggle Progress"), this, TQ_SLOT(slotToggleDefaultProgress()));
       m_contextMenu->insertSeparator();
-      m_contextMenu->insertItem(i18n("Settings..."), this, TQT_SLOT(slotConfigure()));
+      m_contextMenu->insertItem(i18n("Settings..."), this, TQ_SLOT(slotConfigure()));
    }
    if ( item )
        item->setSelected( true );
@@ -707,9 +707,9 @@ void UIServer::slotConfigure()
    if (m_configDialog==0)
    {
       m_configDialog=new ProgressConfigDialog(0);
-//      connect(m_configDialog,TQT_SIGNAL(cancelClicked()), this, TQT_SLOT(slotCancelConfig()));
-      connect(m_configDialog,TQT_SIGNAL(okClicked()), this, TQT_SLOT(slotApplyConfig()));
-      connect(m_configDialog,TQT_SIGNAL(applyClicked()), this, TQT_SLOT(slotApplyConfig()));
+//      connect(m_configDialog,TQ_SIGNAL(cancelClicked()), this, TQ_SLOT(slotCancelConfig()));
+      connect(m_configDialog,TQ_SIGNAL(okClicked()), this, TQ_SLOT(slotApplyConfig()));
+      connect(m_configDialog,TQ_SIGNAL(applyClicked()), this, TQ_SLOT(slotApplyConfig()));
    }
    m_configDialog->m_showSystemTrayCb->setChecked(m_showSystemTray);
    m_configDialog->m_keepOpenCb->setChecked(m_keepListOpen);
@@ -760,8 +760,8 @@ int UIServer::newJob( TQCString observerAppId, bool showProgress )
   bool show = !m_bShowList && showProgress;
 
   ProgressItem *item = new ProgressItem( listProgress, it.current(), observerAppId, s_jobId, show );
-  connect( item, TQT_SIGNAL( jobCanceled( ProgressItem* ) ),
-           TQT_SLOT( slotJobCanceled( ProgressItem* ) ) );
+  connect( item, TQ_SIGNAL( jobCanceled( ProgressItem* ) ),
+           TQ_SLOT( slotJobCanceled( ProgressItem* ) ) );
 
   if ( m_bShowList && !updateTimer->isActive() )
     updateTimer->start( 1000 );
@@ -1205,7 +1205,7 @@ void UIServer::showSSLInfoDialog(const TQString &url, const TDEIO::MetaData &met
                   meta["ssl_cipher_bits"].toInt(),
                   KSSLCertificate::KSSLValidation(meta["ssl_cert_state"].toInt()));
       kdDebug(7024) << "Showing SSL Info dialog" << endl;
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
       if( mainwindow != 0 )
           KWin::setMainWindow( kid, mainwindow );
 #endif
@@ -1233,7 +1233,7 @@ KSSLCertDlgRet UIServer::showSSLCertDialog(const TQString& host, const TQStringL
       kcd->setupDialog(certList);
       kcd->setHost(host);
       kdDebug(7024) << "Showing SSL certificate dialog" << endl;
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
       if( mainwindow != 0 )
           KWin::setMainWindow( kcd, mainwindow );
 #endif
@@ -1374,7 +1374,7 @@ UIServer* UIServer::createInstance()
 
 //------------------------------------------------------------
 
-extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
+extern "C" TDE_EXPORT int kdemain(int argc, char **argv)
 {
     TDELocale::setMainCatalogue("tdelibs");
     //  GS 5/2001 - I changed the name to "TDE" to make it look better
