@@ -133,7 +133,7 @@ namespace KNotify
             TQHeader *header = static_cast<TQHeader*>( parentWidget() );
             int section = 0;
 
-            if ( header->orientation() == Qt::Horizontal )
+            if ( header->orientation() == TQt::Horizontal )
                 section= header->sectionAt( p.x() );
             else
                 section= header->sectionAt( p.y() );
@@ -170,8 +170,8 @@ KNotifyDialog::KNotifyDialog( TQWidget *parent, const char *name, bool modal,
     if ( aboutData )
         addApplicationEvents( aboutData->appName() );
 
-    connect( this, TQT_SIGNAL( okClicked() ), m_notifyWidget, TQT_SLOT( save() ));
-    connect( this, TQT_SIGNAL( applyClicked() ), m_notifyWidget, TQT_SLOT( save() ));
+    connect( this, TQ_SIGNAL( okClicked() ), m_notifyWidget, TQ_SLOT( save() ));
+    connect( this, TQ_SIGNAL( applyClicked() ), m_notifyWidget, TQ_SLOT( save() ));
 }
 
 KNotifyDialog::~KNotifyDialog()
@@ -264,47 +264,47 @@ KNotifyWidget::KNotifyWidget( TQWidget *parent, const char *name,
     d->toolTip = new KNotifyToolTip( header );
 
     m_playButton->setIconSet( SmallIconSet( "media-playback-start" ) );
-    connect( m_playButton, TQT_SIGNAL( clicked() ), TQT_SLOT( playSound() ));
+    connect( m_playButton, TQ_SIGNAL( clicked() ), TQ_SLOT( playSound() ));
 
-    connect( m_listview, TQT_SIGNAL( currentChanged( TQListViewItem * ) ),
-             TQT_SLOT( slotEventChanged( TQListViewItem * ) ));
-    connect( m_listview, TQT_SIGNAL(clicked( TQListViewItem *, const TQPoint&, int)),
-             TQT_SLOT( slotItemClicked( TQListViewItem *, const TQPoint&, int )));
+    connect( m_listview, TQ_SIGNAL( currentChanged( TQListViewItem * ) ),
+             TQ_SLOT( slotEventChanged( TQListViewItem * ) ));
+    connect( m_listview, TQ_SIGNAL(clicked( TQListViewItem *, const TQPoint&, int)),
+             TQ_SLOT( slotItemClicked( TQListViewItem *, const TQPoint&, int )));
 
-    connect( m_playSound, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( soundToggled( bool )) );
-    connect( m_logToFile, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( loggingToggled( bool )) );
-    connect( m_execute, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( executeToggled( bool )) );
-    connect( m_messageBox, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( messageBoxChanged() ) );
-    connect( m_passivePopup, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( messageBoxChanged() ) );
-    connect( m_stderr, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( stderrToggled( bool ) ) );
-    connect( m_taskbar, TQT_SIGNAL( toggled( bool )),
-             TQT_SLOT( taskbarToggled( bool ) ) );
+    connect( m_playSound, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( soundToggled( bool )) );
+    connect( m_logToFile, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( loggingToggled( bool )) );
+    connect( m_execute, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( executeToggled( bool )) );
+    connect( m_messageBox, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( messageBoxChanged() ) );
+    connect( m_passivePopup, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( messageBoxChanged() ) );
+    connect( m_stderr, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( stderrToggled( bool ) ) );
+    connect( m_taskbar, TQ_SIGNAL( toggled( bool )),
+             TQ_SLOT( taskbarToggled( bool ) ) );
 
-    connect( m_soundPath, TQT_SIGNAL( textChanged( const TQString& )),
-             TQT_SLOT( soundFileChanged( const TQString& )));
-    connect( m_logfilePath, TQT_SIGNAL( textChanged( const TQString& )),
-             TQT_SLOT( logfileChanged( const TQString& ) ));
-    connect( m_executePath, TQT_SIGNAL( textChanged( const TQString& )),
-             TQT_SLOT( commandlineChanged( const TQString& ) ));
+    connect( m_soundPath, TQ_SIGNAL( textChanged( const TQString& )),
+             TQ_SLOT( soundFileChanged( const TQString& )));
+    connect( m_logfilePath, TQ_SIGNAL( textChanged( const TQString& )),
+             TQ_SLOT( logfileChanged( const TQString& ) ));
+    connect( m_executePath, TQ_SIGNAL( textChanged( const TQString& )),
+             TQ_SLOT( commandlineChanged( const TQString& ) ));
 
-    connect( m_soundPath, TQT_SIGNAL( openFileDialog( KURLRequester * )),
-             TQT_SLOT( openSoundDialog( KURLRequester * )));
-    connect( m_logfilePath, TQT_SIGNAL( openFileDialog( KURLRequester * )),
-             TQT_SLOT( openLogDialog( KURLRequester * )));
-    connect( m_executePath, TQT_SIGNAL( openFileDialog( KURLRequester * )),
-             TQT_SLOT( openExecDialog( KURLRequester * )));
+    connect( m_soundPath, TQ_SIGNAL( openFileDialog( KURLRequester * )),
+             TQ_SLOT( openSoundDialog( KURLRequester * )));
+    connect( m_logfilePath, TQ_SIGNAL( openFileDialog( KURLRequester * )),
+             TQ_SLOT( openLogDialog( KURLRequester * )));
+    connect( m_executePath, TQ_SIGNAL( openFileDialog( KURLRequester * )),
+             TQ_SLOT( openExecDialog( KURLRequester * )));
 
-    connect( m_extension, TQT_SIGNAL( clicked() ),
-             TQT_SLOT( toggleAdvanced()) );
+    connect( m_extension, TQ_SIGNAL( clicked() ),
+             TQ_SLOT( toggleAdvanced()) );
 
-    connect( m_buttonEnable, TQT_SIGNAL( clicked() ), TQT_SLOT( enableAll() ));
-    connect( m_buttonDisable, TQT_SIGNAL( clicked() ), TQT_SLOT( enableAll() ));
+    connect( m_buttonEnable, TQ_SIGNAL( clicked() ), TQ_SLOT( enableAll() ));
+    connect( m_buttonDisable, TQ_SIGNAL( clicked() ), TQ_SLOT( enableAll() ));
 
     TQString whatsThis = i18n("<qt>You may use the following macros<br>"
         "in the commandline:<br>"
@@ -851,8 +851,8 @@ Event * KNotifyWidget::currentEvent()
 void KNotifyWidget::openSoundDialog( KURLRequester *requester )
 {
     // only need to init this once
-    requester->disconnect( TQT_SIGNAL( openFileDialog( KURLRequester * )),
-                           this, TQT_SLOT( openSoundDialog( KURLRequester * )));
+    requester->disconnect( TQ_SIGNAL( openFileDialog( KURLRequester * )),
+                           this, TQ_SLOT( openSoundDialog( KURLRequester * )));
 
     KFileDialog *fileDialog = requester->fileDialog();
     fileDialog->setCaption( i18n("Select Sound File") );
@@ -887,8 +887,8 @@ void KNotifyWidget::openSoundDialog( KURLRequester *requester )
 void KNotifyWidget::openLogDialog( KURLRequester *requester )
 {
     // only need to init this once
-    requester->disconnect( TQT_SIGNAL( openFileDialog( KURLRequester * )),
-                           this, TQT_SLOT( openLogDialog( KURLRequester * )));
+    requester->disconnect( TQ_SIGNAL( openFileDialog( KURLRequester * )),
+                           this, TQ_SLOT( openLogDialog( KURLRequester * )));
 
     KFileDialog *fileDialog = requester->fileDialog();
     fileDialog->setCaption( i18n("Select Log File") );
@@ -900,8 +900,8 @@ void KNotifyWidget::openLogDialog( KURLRequester *requester )
 void KNotifyWidget::openExecDialog( KURLRequester *requester )
 {
     // only need to init this once
-    requester->disconnect( TQT_SIGNAL( openFileDialog( KURLRequester * )),
-                           this, TQT_SLOT( openExecDialog( KURLRequester * )));
+    requester->disconnect( TQ_SIGNAL( openFileDialog( KURLRequester * )),
+                           this, TQ_SLOT( openExecDialog( KURLRequester * )));
 
 
     KFileDialog *fileDialog = requester->fileDialog();
