@@ -59,13 +59,13 @@ public:
 
         noArrangement = false;
 	ignoreMaximumSize = false;
-	smallColumns = new TDERadioAction( i18n("Small Icons"), 0, TQT_TQOBJECT(parent),
-					 TQT_SLOT( slotSmallColumns() ),
+	smallColumns = new TDERadioAction( i18n("Small Icons"), 0, parent,
+					 TQ_SLOT( slotSmallColumns() ),
 					 parent->actionCollection(),
 					 "small columns" );
 
-	largeRows = new TDERadioAction( i18n("Large Icons"), 0, TQT_TQOBJECT(parent),
-				      TQT_SLOT( slotLargeRows() ),
+	largeRows = new TDERadioAction( i18n("Large Icons"), 0, parent,
+				      TQ_SLOT( slotLargeRows() ),
 				      parent->actionCollection(),
 				      "large rows" );
 
@@ -75,22 +75,22 @@ public:
         previews = new TDEToggleAction( i18n("Thumbnail Previews"), 0,
                                       parent->actionCollection(),
                                       "show previews" );
-        zoomIn = KStdAction::zoomIn( TQT_TQOBJECT(parent), TQT_SLOT( zoomIn() ),
+        zoomIn = KStdAction::zoomIn( parent, TQ_SLOT( zoomIn() ),
                                      parent->actionCollection(), "zoomIn" );
-        zoomOut = KStdAction::zoomOut( TQT_TQOBJECT(parent), TQT_SLOT( zoomOut() ),
+        zoomOut = KStdAction::zoomOut( parent, TQ_SLOT( zoomOut() ),
                                      parent->actionCollection(), "zoomOut" );
 
         previews->setGroup("previews");
         zoomIn->setGroup("previews");
         zoomOut->setGroup("previews");
 
-        connect( previews, TQT_SIGNAL( toggled( bool )),
-                 parent, TQT_SLOT( slotPreviewsToggled( bool )));
+        connect( previews, TQ_SIGNAL( toggled( bool )),
+                 parent, TQ_SLOT( slotPreviewsToggled( bool )));
 
-        connect( &previewTimer, TQT_SIGNAL( timeout() ),
-                 parent, TQT_SLOT( showPreviews() ));
-        connect( &autoOpenTimer, TQT_SIGNAL( timeout() ),
-                 parent, TQT_SLOT( slotAutoOpen() ));
+        connect( &previewTimer, TQ_SIGNAL( timeout() ),
+                 parent, TQ_SLOT( showPreviews() ));
+        connect( &autoOpenTimer, TQ_SIGNAL( timeout() ),
+                 parent, TQ_SLOT( slotAutoOpen() ));
     }
 
     ~KFileIconViewPrivate() {
@@ -133,21 +133,21 @@ KFileIconView::KFileIconView(TQWidget *parent, const char *name)
     slotSmallColumns();
     d->smallColumns->setChecked( true );
 
-    connect( this, TQT_SIGNAL( returnPressed(TQIconViewItem *) ),
-	     TQT_SLOT( slotActivate( TQIconViewItem *) ) );
+    connect( this, TQ_SIGNAL( returnPressed(TQIconViewItem *) ),
+	     TQ_SLOT( slotActivate( TQIconViewItem *) ) );
 
     // we want single click _and_ double click (as convenience)
-    connect( this, TQT_SIGNAL( clicked(TQIconViewItem *, const TQPoint&) ),
-	     TQT_SLOT( selected( TQIconViewItem *) ) );
-    connect( this, TQT_SIGNAL( doubleClicked(TQIconViewItem *, const TQPoint&) ),
-	     TQT_SLOT( slotActivate( TQIconViewItem *) ) );
+    connect( this, TQ_SIGNAL( clicked(TQIconViewItem *, const TQPoint&) ),
+	     TQ_SLOT( selected( TQIconViewItem *) ) );
+    connect( this, TQ_SIGNAL( doubleClicked(TQIconViewItem *, const TQPoint&) ),
+	     TQ_SLOT( slotActivate( TQIconViewItem *) ) );
 
-    connect( this, TQT_SIGNAL( onItem( TQIconViewItem * ) ),
-	     TQT_SLOT( showToolTip( TQIconViewItem * ) ) );
-    connect( this, TQT_SIGNAL( onViewport() ),
-	     TQT_SLOT( removeToolTip() ) );
-    connect( this, TQT_SIGNAL( contextMenuRequested(TQIconViewItem*,const TQPoint&)),
-	     TQT_SLOT( slotActivateMenu( TQIconViewItem*, const TQPoint& ) ) );
+    connect( this, TQ_SIGNAL( onItem( TQIconViewItem * ) ),
+	     TQ_SLOT( showToolTip( TQIconViewItem * ) ) );
+    connect( this, TQ_SIGNAL( onViewport() ),
+	     TQ_SLOT( removeToolTip() ) );
+    connect( this, TQ_SIGNAL( contextMenuRequested(TQIconViewItem*,const TQPoint&)),
+	     TQ_SLOT( slotActivateMenu( TQIconViewItem*, const TQPoint& ) ) );
 
     KFile::SelectionMode sm = KFileView::selectionMode();
     switch ( sm ) {
@@ -167,11 +167,11 @@ KFileIconView::KFileIconView(TQWidget *parent, const char *name)
     }
 
     if ( sm == KFile::Multi || sm == KFile::Extended )
-	connect( this, TQT_SIGNAL( selectionChanged() ),
-		 TQT_SLOT( slotSelectionChanged() ));
+	connect( this, TQ_SIGNAL( selectionChanged() ),
+		 TQ_SLOT( slotSelectionChanged() ));
     else
-	connect( this, TQT_SIGNAL( selectionChanged( TQIconViewItem * )),
-		 TQT_SLOT( highlighted( TQIconViewItem * )));
+	connect( this, TQ_SIGNAL( selectionChanged( TQIconViewItem * )),
+		 TQ_SLOT( highlighted( TQIconViewItem * )));
 
     viewport()->installEventFilter( this );
 
@@ -398,8 +398,8 @@ void KFileIconView::highlighted( TQIconViewItem *item )
 
 void KFileIconView::setSelectionMode( KFile::SelectionMode sm )
 {
-    disconnect( TQT_SIGNAL( selectionChanged() ), this );
-    disconnect( TQT_SIGNAL( selectionChanged( TQIconViewItem * )), this );
+    disconnect( TQ_SIGNAL( selectionChanged() ), this );
+    disconnect( TQ_SIGNAL( selectionChanged( TQIconViewItem * )), this );
 
     KFileView::setSelectionMode( sm );
     switch ( KFileView::selectionMode() ) {
@@ -419,11 +419,11 @@ void KFileIconView::setSelectionMode( KFile::SelectionMode sm )
     }
 
     if ( sm == KFile::Multi || sm == KFile::Extended )
-	connect( this, TQT_SIGNAL( selectionChanged() ),
-		 TQT_SLOT( slotSelectionChanged() ));
+	connect( this, TQ_SIGNAL( selectionChanged() ),
+		 TQ_SLOT( slotSelectionChanged() ));
     else
-	connect( this, TQT_SIGNAL( selectionChanged( TQIconViewItem * )),
-		 TQT_SLOT( highlighted( TQIconViewItem * )));
+	connect( this, TQ_SIGNAL( selectionChanged( TQIconViewItem * )),
+		 TQ_SLOT( highlighted( TQIconViewItem * )));
 }
 
 bool KFileIconView::isSelected( const KFileItem *i ) const
@@ -593,12 +593,12 @@ void KFileIconView::showPreviews()
     d->job = TDEIO::filePreview(*items(), d->previewIconSize,d->previewIconSize);
     d->job->setIgnoreMaximumSize(d->ignoreMaximumSize);
 
-    connect( d->job, TQT_SIGNAL( result( TDEIO::Job * )),
-             this, TQT_SLOT( slotPreviewResult( TDEIO::Job * )));
-    connect( d->job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap& )),
-             TQT_SLOT( gotPreview( const KFileItem*, const TQPixmap& ) ));
-//     connect( d->job, TQT_SIGNAL( failed( const KFileItem* )),
-//              this, TQT_SLOT( slotFailed( const KFileItem* ) ));
+    connect( d->job, TQ_SIGNAL( result( TDEIO::Job * )),
+             this, TQ_SLOT( slotPreviewResult( TDEIO::Job * )));
+    connect( d->job, TQ_SIGNAL( gotPreview( const KFileItem*, const TQPixmap& )),
+             TQ_SLOT( gotPreview( const KFileItem*, const TQPixmap& ) ));
+//     connect( d->job, TQ_SIGNAL( failed( const KFileItem* )),
+//              this, TQ_SLOT( slotFailed( const KFileItem* ) ));
 }
 
 void KFileIconView::slotPreviewResult( TDEIO::Job *job )
