@@ -855,7 +855,7 @@ pid_t KDEDesktopMimeType::runFSDevice( const KURL& _url, const KSimpleConfig &cf
     if ( fstype == "Default" ) // KDE-1 thing
       fstype = TQString::null;
     TQString point = cfg.readEntry( "MountPoint" );
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
     (void) new KAutoMount( ro, fstype, dev, point, _url.path() );
 #endif
     retval = -1; // we don't want to return 0, but we don't want to return a pid
@@ -1138,7 +1138,7 @@ void KDEDesktopMimeType::executeService( const KURL::List& urls, KDEDesktopMimeT
       if ( fstype == "Default" ) // KDE-1 thing
           fstype = TQString::null;
       TQString point = cfg.readEntry( "MountPoint" );
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
       (void)new KAutoMount( ro, fstype, dev, point, path, false );
 #endif
     }
@@ -1148,7 +1148,7 @@ void KDEDesktopMimeType::executeService( const KURL::List& urls, KDEDesktopMimeT
       if ( mp.isEmpty() )
         return;
 
-#ifndef Q_WS_WIN
+#ifndef TQ_WS_WIN
       (void)new KAutoUnmount( mp, path );
 #endif
     }
