@@ -142,7 +142,7 @@ public:
      *
      * @deprecated
      */
-    KDE_DEPRECATED bool hasBeenFiltered() const { return true; }
+    TDE_DEPRECATED bool hasBeenFiltered() const { return true; }
 
     /**
      * Returns the filtered or the original URL.
