@@ -1,5 +1,4 @@
-/* -*- indent-tabs-mode: t; tab-width: 4; c-basic-offset:4 -*-
-
+/*
    This file is part of the KDE libraries
    Copyright (C) 2000 David Smith <dsmith@algonet.se>
    Copyright (C) 2004 Scott Wheeler <wheeler@kde.org>
@@ -224,8 +223,7 @@ void DirectoryListThread::run()
 
 		// Loop through all directory entries
 		// Solaris and IRIX dirent structures do not allocate space for d_name. On
-		// systems that do (HP-UX, Linux, Tru64 UNIX), we overallocate space but
-		// that's ok.
+		// systems that do (HP-UX, Linux), we overallocate space but that's ok.
 #ifndef HAVE_READDIR_R
 		struct dirent *dirEntry = 0;
 		while ( !terminationRequested() &&
@@ -1334,12 +1332,12 @@ void KURLCompletion::slotIOFinished( TDEIO::Job * job )
 		assert( d->list_job );
 
 		connect( d->list_job,
-				TQT_SIGNAL(result(TDEIO::Job*)),
-				TQT_SLOT(slotIOFinished(TDEIO::Job*)) );
+				TQ_SIGNAL(result(TDEIO::Job*)),
+				TQ_SLOT(slotIOFinished(TDEIO::Job*)) );
 
 		connect( d->list_job,
-				TQT_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList&)),
-				TQT_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList&)) );
+				TQ_SIGNAL( entries( TDEIO::Job*, const TDEIO::UDSEntryList&)),
+				TQ_SLOT( slotEntries( TDEIO::Job*, const TDEIO::UDSEntryList&)) );
 
 		delete kurl;
 	}
