@@ -108,7 +108,7 @@ static void appendACLAtoms( const TQCString & path, UDSEntry& entry,
                             mode_t type, bool withACL );
 #endif
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 int kdemain( int argc, char **argv )
 {
