@@ -54,7 +54,7 @@ class KMDI_EXPORT KMdiChildArea : public TQFrame
 	friend class KMdiChildFrmCaption;
 	friend class KMdiChildFrm;
 
-Q_OBJECT
+TQ_OBJECT
 
 	// attributes
 public:
@@ -192,7 +192,7 @@ public:
 	 * TDEGlobalSettings::inactiveTitleColor() and TDEGlobalSettings::inactiveTextColor() instead.
 	 */
 	static void getCaptionColors( const TQPalette &pal, TQColor &activeBG, TQColor &activeFG,
-	                              TQColor &inactiveBG, TQColor &inactiveFG ) KDE_DEPRECATED;
+	                              TQColor &inactiveBG, TQColor &inactiveFG ) TDE_DEPRECATED;
 
 public slots:
 	/**
