@@ -33,21 +33,21 @@ void BrowserInterface::callMethod( const char *name, const TQVariant &argument )
         case TQVariant::Invalid:
             break;
         case TQVariant::String:
-            static_TQUType_TQString.set( o + 1, argument.toString() );
+            static_QUType_TQString.set( o + 1, argument.toString() );
             break;
         case TQVariant::StringList:
 	    strLst = argument.toStringList();
-            static_TQUType_ptr.set( o + 1, &strLst );
+            static_QUType_ptr.set( o + 1, &strLst );
             break;
         case TQVariant::Int:
-            static_TQUType_int.set( o + 1, argument.toInt() );
+            static_QUType_int.set( o + 1, argument.toInt() );
             break;
         case TQVariant::UInt:
 	    i = argument.toUInt();
-	    static_TQUType_ptr.set( o + 1, &i );
+	    static_QUType_ptr.set( o + 1, &i );
             break;
         case TQVariant::Bool:
-	    static_TQUType_bool.set( o + 1, argument.toBool() );
+	    static_QUType_bool.set( o + 1, argument.toBool() );
             break;
         default: return;
     }
