@@ -15,7 +15,7 @@ class TQMultiLineEdit;
  */
 class NotepadPart : public KParts::ReadWritePart
 {
-  Q_OBJECT
+  TQ_OBJECT
 public:
   NotepadPart( TQWidget*, const char* widgetName,
                TQObject* parent, const char* name,
