@@ -234,7 +234,7 @@ void KMCupsUiManager::setupPrintDialogPages(TQPtrList<KPrintDialogPage>* pages)
 void KMCupsUiManager::setupJobViewer(TQListView *lv)
 {
 	lv->addColumn(i18n("Priority"));
-	lv->setColumnAlignment(lv->columns()-1, Qt::AlignRight|Qt::AlignVCenter);
+	lv->setColumnAlignment(lv->columns()-1, TQt::AlignRight|TQt::AlignVCenter);
 	lv->addColumn(i18n("Billing Information"));
-	lv->setColumnAlignment(lv->columns()-1, Qt::AlignRight|Qt::AlignVCenter);
+	lv->setColumnAlignment(lv->columns()-1, TQt::AlignRight|TQt::AlignVCenter);
 }
