@@ -27,7 +27,7 @@ class TQComboBox;
 
 class KMWQuota : public KMWizardPage
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KMWQuota(TQWidget *parent = 0, const char *name = 0);
 	virtual ~KMWQuota();
