@@ -29,7 +29,7 @@ class KIntNumInput;
 
 class KPSchedulePage : public KPrintDialogPage
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KPSchedulePage(TQWidget *parent = 0, const char *name = 0);
 	~KPSchedulePage();
