@@ -91,7 +91,7 @@ void DriverItem::paintCell(TQPainter *p, const TQColorGroup& cg, int, int width,
 	if (!m_item || !m_item->isOption() || isSelected())
 	{
 		p->setPen((isSelected() ? cg.highlightedText() : (m_conflict ? red : cg.text())));
-		p->drawText(w,0,width-w,height(),Qt::AlignLeft|Qt::AlignVCenter,text(0));
+		p->drawText(w,0,width-w,height(),TQt::AlignLeft|TQt::AlignVCenter,text(0));
 	}
 	else
 	{
@@ -99,17 +99,17 @@ void DriverItem::paintCell(TQPainter *p, const TQColorGroup& cg, int, int width,
 		TQString	s(m_item->get("text") + ": <");
 		w1 = p->fontMetrics().width(s);
 		p->setPen(cg.text());
-		p->drawText(w,0,w1,height(),Qt::AlignLeft|Qt::AlignVCenter,s);
+		p->drawText(w,0,w1,height(),TQt::AlignLeft|TQt::AlignVCenter,s);
 		w += w1;
 		p->setPen((m_conflict ? red : darkGreen));
 		s = m_item->prettyText();
 		w1 = p->fontMetrics().width(s);
-		p->drawText(w,0,w1,height(),Qt::AlignLeft|Qt::AlignVCenter,s);
+		p->drawText(w,0,w1,height(),TQt::AlignLeft|TQt::AlignVCenter,s);
 		w += w1;
 		p->setPen(cg.text());
 		s = TQString::fromLatin1(">");
 		w1 = p->fontMetrics().width(s);
-		p->drawText(w,0,w1,height(),Qt::AlignLeft|Qt::AlignVCenter,s);
+		p->drawText(w,0,w1,height(),TQt::AlignLeft|TQt::AlignVCenter,s);
 	}
 }
 
