@@ -53,7 +53,7 @@ bool Foomatic2Loader::readFromFile( const TQString& filename )
 	TQFile f( filename );
 	m_foodata.clear();
 	if ( f.open( IO_ReadOnly ) )
-		return read( TQT_TQIODEVICE(&f) );
+		return read( &f );
 	return false;
 }
 
@@ -63,7 +63,7 @@ bool Foomatic2Loader::readFromBuffer( const TQString& buffer )
 	TQBuffer d( buf );
 	m_foodata.clear();
 	if ( d.open( IO_ReadOnly ) )
-		return read( TQT_TQIODEVICE(&d) );
+		return read( &d );
 	return false;
 }
 
