@@ -116,11 +116,11 @@ void KPQtPage::init()
 	m_pagesize = new TQComboBox(this);
           TQWhatsThis::add(m_pagesize, whatsThisPageSizeOtPageLabel);
 	TQLabel	*m_pagesizelabel = new TQLabel(i18n("Page s&ize:"), this);
-	m_pagesizelabel->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
+	m_pagesizelabel->setAlignment(TQt::AlignVCenter|TQt::AlignRight);
 	m_pagesizelabel->setBuddy(m_pagesize);
-	m_orientbox = new TQButtonGroup(0, Qt::Vertical, i18n("Orientation"), this);
+	m_orientbox = new TQButtonGroup(0, TQt::Vertical, i18n("Orientation"), this);
           TQWhatsThis::add(m_orientbox, whatsThisOrientationOtPageLabel);
-	m_colorbox = new TQButtonGroup(0, Qt::Vertical, i18n("Color Mode"), this);
+	m_colorbox = new TQButtonGroup(0, TQt::Vertical, i18n("Color Mode"), this);
           TQWhatsThis::add(m_colorbox, whatsThisColorModeOtPageLabel);
 	TQRadioButton	*m_portrait = new TQRadioButton(i18n("&Portrait"), m_orientbox);
           TQWhatsThis::add(m_portrait, whatsThisOrientationOtPageLabel);
@@ -129,7 +129,7 @@ void KPQtPage::init()
           TQWhatsThis::add(m_landscape, whatsThisOrientationOtPageLabel);
 
 	m_orientpix = new TQLabel(m_orientbox);
-	m_orientpix->setAlignment(Qt::AlignCenter);
+	m_orientpix->setAlignment(TQt::AlignCenter);
           TQWhatsThis::add(m_orientpix, whatsThisOrientationOtPageLabel);
 
 	TQRadioButton	*m_color = new TQRadioButton(i18n("Colo&r"), m_colorbox);
@@ -137,10 +137,10 @@ void KPQtPage::init()
 
 	TQRadioButton	*m_grayscale = new TQRadioButton(i18n("&Grayscale"), m_colorbox);
 	m_colorpix = new TQLabel(m_colorbox);
-	m_colorpix->setAlignment(Qt::AlignCenter);
+	m_colorpix->setAlignment(TQt::AlignCenter);
           TQWhatsThis::add(m_colorpix, whatsThisColorModeOtPageLabel);
 
-	m_nupbox = new TQButtonGroup(0, Qt::Vertical, i18n("Pages per Sheet"), this);
+	m_nupbox = new TQButtonGroup(0, TQt::Vertical, i18n("Pages per Sheet"), this);
         //  TQWhatsThis::add(m_nupbox, whatsThisPagesPerSheetOtPageLabel);
 	TQRadioButton	*m_nup1 = new TQRadioButton("&1", m_nupbox);
           TQWhatsThis::add(m_nup1, whatsThisPagesPerSheetOtPageLabel);
@@ -152,7 +152,7 @@ void KPQtPage::init()
           TQWhatsThis::add(m_nupother, whatsThisPagesPerSheetOtPageLabel);
 
 	m_nuppix = new TQLabel(m_nupbox);
-	m_nuppix->setAlignment(Qt::AlignCenter);
+	m_nuppix->setAlignment(TQt::AlignCenter);
           TQWhatsThis::add(m_nuppix, whatsThisPagesPerSheetOtPageLabel);
 
 	// layout creation
@@ -218,9 +218,9 @@ void KPQtPage::init()
 	}
 
 	// connections
-	connect(m_orientbox,TQT_SIGNAL(clicked(int)),TQT_SLOT(slotOrientationChanged(int)));
-	connect(m_colorbox,TQT_SIGNAL(clicked(int)),TQT_SLOT(slotColorModeChanged(int)));
-	connect(m_nupbox,TQT_SIGNAL(clicked(int)),TQT_SLOT(slotNupChanged(int)));
+	connect(m_orientbox,TQ_SIGNAL(clicked(int)),TQ_SLOT(slotOrientationChanged(int)));
+	connect(m_colorbox,TQ_SIGNAL(clicked(int)),TQ_SLOT(slotColorModeChanged(int)));
+	connect(m_nupbox,TQ_SIGNAL(clicked(int)),TQ_SLOT(slotNupChanged(int)));
 }
 
 void KPQtPage::slotOrientationChanged(int ID)
