@@ -27,7 +27,7 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 #include <tqvaluelist.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <tdelibs_export.h>
 
 #include <tdeprint/kpreloadobject.h>
@@ -326,7 +326,7 @@ public:
 	 *
 	 * @see pageList()
 	 */
-	int fromPage() const KDE_DEPRECATED;
+	int fromPage() const TDE_DEPRECATED;
 	/**
 	 * Returns the last page to be printed.
          * @deprecated Applications
