@@ -28,7 +28,7 @@ class DrMain;
 
 class KMWDriverTest : public KMWizardPage
 {
-	Q_OBJECT
+	TQ_OBJECT
 public:
 	KMWDriverTest(TQWidget *parent = 0, const char *name = 0);
 	~KMWDriverTest();
