@@ -60,7 +60,7 @@
 
 #define CONFIGURATION_FILE_SEPARATOR ';'
 
-KDE_EXPORT KRsync::KRsync (TQObject* parent, const char* name)
+TDE_EXPORT KRsync::KRsync (TQObject* parent, const char* name)
                 : TQObject (parent, name), m_progressDialog(0), m_progressDialogExists(false), m_bSettingsLoaded(false), m_bInSpecialSync(false)
 {
     loadSettings();
@@ -77,7 +77,7 @@ KDE_EXPORT KRsync::KRsync (TQObject* parent, const char* name)
     redirectPass = ""; // FIXME: just a workaround for konq deficiencies
 }
 
-KDE_EXPORT KRsync::~KRsync()
+TDE_EXPORT KRsync::~KRsync()
 {
 
 }
@@ -152,7 +152,7 @@ close_master:
 /**
 creates the unidirectional sync subprocess
 */
-KDE_EXPORT bool KRsync::syncUnidirectional(TQString synccommand, TQString syncflags, int parameter_order, TQString localfolder, TQString remotepath) {
+TDE_EXPORT bool KRsync::syncUnidirectional(TQString synccommand, TQString syncflags, int parameter_order, TQString localfolder, TQString remotepath) {
     int fd[2];
     int rc, flags;
     thisFn = TQString();
@@ -291,7 +291,7 @@ KDE_EXPORT bool KRsync::syncUnidirectional(TQString synccommand, TQString syncfl
 /**
 creates the bidirectional sync subprocess
 */
-KDE_EXPORT bool KRsync::syncBidirectional(TQString synccommand, TQString syncflags, int parameter_order, TQString localfolder, TQString remotepath) {
+TDE_EXPORT bool KRsync::syncBidirectional(TQString synccommand, TQString syncflags, int parameter_order, TQString localfolder, TQString remotepath) {
     int fd[2];
     int rc, flags;
     thisFn = TQString();
@@ -430,7 +430,7 @@ KDE_EXPORT bool KRsync::syncBidirectional(TQString synccommand, TQString syncfla
 /**
 writes one chunk of data to stdin of child process
 */
-KDE_EXPORT void KRsync::writeChild(const char *buf, TDEIO::fileoffset_t len) {
+TDE_EXPORT void KRsync::writeChild(const char *buf, TDEIO::fileoffset_t len) {
     if (outBufPos >= 0 && outBuf) {
 #if 0
         TQString debug;
@@ -447,7 +447,7 @@ KDE_EXPORT void KRsync::writeChild(const char *buf, TDEIO::fileoffset_t len) {
 /**
 manages initial communication setup including password queries
 */
-KDE_EXPORT int KRsync::establishConnectionRsync(char *buffer, TDEIO::fileoffset_t len) {
+TDE_EXPORT int KRsync::establishConnectionRsync(char *buffer, TDEIO::fileoffset_t len) {
     TQString buf;
     buf.setLatin1(buffer,len);
     int pos;
@@ -562,7 +562,7 @@ KDE_EXPORT int KRsync::establishConnectionRsync(char *buffer, TDEIO::fileoffset_
 /**
 manages initial communication setup including password queries
 */
-KDE_EXPORT int KRsync::establishConnectionUnison(char *buffer, TDEIO::fileoffset_t len, TQString localfolder, TQString remotepath) {
+TDE_EXPORT int KRsync::establishConnectionUnison(char *buffer, TDEIO::fileoffset_t len, TQString localfolder, TQString remotepath) {
     TQString buf;
     buf.setLatin1(buffer,len);
     int pos;
@@ -746,7 +746,7 @@ Forced close of the connection
 This function gets called from the application side of the universe,
 it shouldn't send any response.
  */
-KDE_EXPORT void KRsync::closeConnection(){
+TDE_EXPORT void KRsync::closeConnection(){
     myDebug( << "closeConnection()" << endl);
     shutdownConnection(true, false);
 }
@@ -754,7 +754,7 @@ KDE_EXPORT void KRsync::closeConnection(){
 /**
 Closes the connection
  */
-KDE_EXPORT void KRsync::shutdownConnection(bool forced, bool wait){
+TDE_EXPORT void KRsync::shutdownConnection(bool forced, bool wait){
     if (childPid) {
         kill(childPid,SIGTERM); // We may not have permission...
         childPid = 0;
@@ -775,7 +775,7 @@ KDE_EXPORT void KRsync::shutdownConnection(bool forced, bool wait){
 //
 // --------------------------------------------------------------------------------------------
 
-KDE_EXPORT void KRsync::saveSettings()
+TDE_EXPORT void KRsync::saveSettings()
 {
   TDEConfig cfg ("rsyncrc", false, false);
   cfg.setGroup ("General");
@@ -784,7 +784,7 @@ KDE_EXPORT void KRsync::saveSettings()
   cfg.sync();
 }
 
-KDE_EXPORT void KRsync::loadSettings()
+TDE_EXPORT void KRsync::loadSettings()
 {
   if (m_bSettingsLoaded)
     return;
@@ -798,7 +798,7 @@ KDE_EXPORT void KRsync::loadSettings()
   m_bSettingsLoaded = true;
 }
 
-KDE_EXPORT void KRsync::executeLogoutAutoSync()
+TDE_EXPORT void KRsync::executeLogoutAutoSync()
 {
   for (TQStringList::Iterator i(cfgautosync_onlogout_list.begin()); i != cfgautosync_onlogout_list.end(); ++i) {
 	setCurrentDirectoryURL(*i);
@@ -808,7 +808,7 @@ KDE_EXPORT void KRsync::executeLogoutAutoSync()
   }
 }
 
-KDE_EXPORT TQString KRsync::findLocalFolderByName(TQString folderurl)
+TDE_EXPORT TQString KRsync::findLocalFolderByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -827,7 +827,7 @@ KDE_EXPORT TQString KRsync::findLocalFolderByName(TQString folderurl)
   return NULL;
 }
 
-KDE_EXPORT TQString KRsync::findSyncMethodByName(TQString folderurl)
+TDE_EXPORT TQString KRsync::findSyncMethodByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -846,7 +846,7 @@ KDE_EXPORT TQString KRsync::findSyncMethodByName(TQString folderurl)
   return NULL;
 }
 
-KDE_EXPORT TQString KRsync::findLoginSyncEnabledByName(TQString folderurl)
+TDE_EXPORT TQString KRsync::findLoginSyncEnabledByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -865,7 +865,7 @@ KDE_EXPORT TQString KRsync::findLoginSyncEnabledByName(TQString folderurl)
   return NULL;
 }
 
-KDE_EXPORT TQString KRsync::findLogoutSyncEnabledByName(TQString folderurl)
+TDE_EXPORT TQString KRsync::findLogoutSyncEnabledByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -884,7 +884,7 @@ KDE_EXPORT TQString KRsync::findLogoutSyncEnabledByName(TQString folderurl)
   return NULL;
 }
 
-KDE_EXPORT TQString KRsync::findTimedSyncEnabledByName(TQString folderurl)
+TDE_EXPORT TQString KRsync::findTimedSyncEnabledByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -903,7 +903,7 @@ KDE_EXPORT TQString KRsync::findTimedSyncEnabledByName(TQString folderurl)
   return NULL;
 }
 
-KDE_EXPORT int KRsync::deleteLocalFolderByName(TQString folderurl)
+TDE_EXPORT int KRsync::deleteLocalFolderByName(TQString folderurl)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -923,7 +923,7 @@ KDE_EXPORT int KRsync::deleteLocalFolderByName(TQString folderurl)
   return 1;
 }
 
-KDE_EXPORT int KRsync::addLocalFolderByName(TQString folderurl, TQString remoteurl, TQString syncmethod, TQString excludelist, TQString sync_on_login, TQString sync_on_logout, TQString sync_timed_interval)
+TDE_EXPORT int KRsync::addLocalFolderByName(TQString folderurl, TQString remoteurl, TQString syncmethod, TQString excludelist, TQString sync_on_login, TQString sync_on_logout, TQString sync_timed_interval)
 {
   TQString folderurl_stripped;
   folderurl_stripped = folderurl;
@@ -938,12 +938,12 @@ KDE_EXPORT int KRsync::addLocalFolderByName(TQString folderurl, TQString remoteu
   return 1;
 }
 
-KDE_EXPORT void KRsync::setCurrentDirectoryURL (KURL url)
+TDE_EXPORT void KRsync::setCurrentDirectoryURL (KURL url)
 {
 	m_pURL = url;
 }
 
-KDE_EXPORT void KRsync::slotSetup()
+TDE_EXPORT void KRsync::slotSetup()
 {
 	KURL url = m_pURL;
 
@@ -981,7 +981,7 @@ KDE_EXPORT void KRsync::slotSetup()
 	connect (m_configDialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(slotSetupCancelled()));
 }
 
-KDE_EXPORT void KRsync::slotSetupOK()
+TDE_EXPORT void KRsync::slotSetupOK()
 {
 	KURL url = m_pURL;
 
@@ -1019,12 +1019,12 @@ KDE_EXPORT void KRsync::slotSetupOK()
 	emit setupDone();
 }
 
-KDE_EXPORT void KRsync::slotSetupCancelled()
+TDE_EXPORT void KRsync::slotSetupCancelled()
 {
 	emit setupDone();
 }
 
-KDE_EXPORT void KRsync::slotRsyncCancelled()
+TDE_EXPORT void KRsync::slotRsyncCancelled()
 {
         shutdownConnection(true, true);
         if (m_progressDialogExists == true) {
@@ -1034,7 +1034,7 @@ KDE_EXPORT void KRsync::slotRsyncCancelled()
         emit transferDone();
 }
 
-KDE_EXPORT void KRsync::slotUnisonCancelled()
+TDE_EXPORT void KRsync::slotUnisonCancelled()
 {
         shutdownConnection(true, true);
         if (m_progressDialogExists == true) {
@@ -1046,7 +1046,7 @@ KDE_EXPORT void KRsync::slotUnisonCancelled()
         emit transferDone();
 }
 
-KDE_EXPORT void KRsync::slotSync()
+TDE_EXPORT void KRsync::slotSync()
 {
 	KURL url = m_pURL;
 
