@@ -28,7 +28,7 @@
 
 class BackgroundTest : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     BackgroundTest();
 
