@@ -120,9 +120,9 @@ KBugReport::KBugReport( TQWidget * parentw, bool modal, const TDEAboutData *abou
     // Configure email button
     m_configureEmail = new TQPushButton( i18n("Configure Email..."),
                                         parent );
-    connect( m_configureEmail, TQT_SIGNAL( clicked() ), this,
-             TQT_SLOT( slotConfigureEmail() ) );
-    glay->addMultiCellWidget( m_configureEmail, 0, 2, 2, 2, (Qt::AlignmentFlags)(AlignTop|AlignRight) );
+    connect( m_configureEmail, TQ_SIGNAL( clicked() ), this,
+             TQ_SLOT( slotConfigureEmail() ) );
+    glay->addMultiCellWidget( m_configureEmail, 0, 2, 2, 2, TQt::AlignTop|TQt::AlignRight );
 
     // To
     qwtstr = i18n( "The email address this bug report is sent to." );
@@ -152,7 +152,7 @@ KBugReport::KBugReport( TQWidget * parentw, bool modal, const TDEAboutData *abou
   d->appcombo = new KComboBox( false, parent, "app");
   TQWhatsThis::add( d->appcombo, qwtstr );
   d->appcombo->insertStrList((const char**)packages);
-  connect(d->appcombo, TQT_SIGNAL(activated(int)), TQT_SLOT(appChanged(int)));
+  connect(d->appcombo, TQ_SIGNAL(activated(int)), TQ_SLOT(appChanged(int)));
   d->appname = TQString::fromLatin1( m_aboutData
                                     ? m_aboutData->productName()
                                     : tqApp->name() );
@@ -272,8 +272,8 @@ KBugReport::KBugReport( TQWidget * parentw, bool modal, const TDEAboutData *abou
     lay->addWidget( d->submitBugButton );
     lay->addSpacing(10);
 
-    connect( d->submitBugButton, TQT_SIGNAL(clicked()),
-             this, TQT_SLOT(slotOk()));
+    connect( d->submitBugButton, TQ_SIGNAL(clicked()),
+             this, TQ_SLOT(slotOk()));
   }
 }
 
@@ -321,7 +321,7 @@ void KBugReport::slotConfigureEmail()
   if (m_process) return;
   m_process = new TDEProcess;
   *m_process << TQString::fromLatin1("tdecmshell") << TQString::fromLatin1("kcm_useraccount");
-  connect(m_process, TQT_SIGNAL(processExited(TDEProcess *)), TQT_SLOT(slotSetFrom()));
+  connect(m_process, TQ_SIGNAL(processExited(TDEProcess *)), TQ_SLOT(slotSetFrom()));
   if (!m_process->start())
   {
     kdDebug() << "Couldn't start tdecmshell.." << endl;
