@@ -68,7 +68,7 @@
 #include "config.h"
 #endif
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/Xlib.h> 
 
 // defined in qapplication_x11.cpp
@@ -191,23 +191,23 @@ static void createStandardPalette()
 
     int i = 0;
 
-    standardPalette[i++] = Qt::red;
-    standardPalette[i++] = Qt::green;
-    standardPalette[i++] = Qt::blue;
-    standardPalette[i++] = Qt::cyan;
-    standardPalette[i++] = Qt::magenta;
-    standardPalette[i++] = Qt::yellow;
-    standardPalette[i++] = Qt::darkRed;
-    standardPalette[i++] = Qt::darkGreen;
-    standardPalette[i++] = Qt::darkBlue;
-    standardPalette[i++] = Qt::darkCyan;
-    standardPalette[i++] = Qt::darkMagenta;
-    standardPalette[i++] = Qt::darkYellow;
-    standardPalette[i++] = Qt::white;
-    standardPalette[i++] = Qt::lightGray;
-    standardPalette[i++] = Qt::gray;
-    standardPalette[i++] = Qt::darkGray;
-    standardPalette[i++] = Qt::black;
+    standardPalette[i++] = TQt::red;
+    standardPalette[i++] = TQt::green;
+    standardPalette[i++] = TQt::blue;
+    standardPalette[i++] = TQt::cyan;
+    standardPalette[i++] = TQt::magenta;
+    standardPalette[i++] = TQt::yellow;
+    standardPalette[i++] = TQt::darkRed;
+    standardPalette[i++] = TQt::darkGreen;
+    standardPalette[i++] = TQt::darkBlue;
+    standardPalette[i++] = TQt::darkCyan;
+    standardPalette[i++] = TQt::darkMagenta;
+    standardPalette[i++] = TQt::darkYellow;
+    standardPalette[i++] = TQt::white;
+    standardPalette[i++] = TQt::lightGray;
+    standardPalette[i++] = TQt::gray;
+    standardPalette[i++] = TQt::darkGray;
+    standardPalette[i++] = TQt::black;
 }
 
 
@@ -263,7 +263,7 @@ void KHSSelector::drawPalette( TQPixmap *pixmap )
 //-----------------------------------------------------------------------------
 
 KValueSelector::KValueSelector( TQWidget *parent, const char *name )
-	: TDESelector( Qt::Vertical, parent, name ), _hue(0), _sat(0)
+	: TDESelector( TQt::Vertical, parent, name ), _hue(0), _sat(0)
 {
 	setRange( 0, 255 );
 	pixmap.setOptimization( TQPixmap::BestOptim );
@@ -300,7 +300,7 @@ void KValueSelector::drawPalette( TQPixmap *pixmap )
 	uint *p;
 	TQRgb rgb;
 
-	if ( orientation() == Qt::Horizontal )
+	if ( orientation() == TQt::Horizontal )
 	{
 		for ( int v = 0; v < ySize; v++ )
 		{
@@ -315,7 +315,7 @@ void KValueSelector::drawPalette( TQPixmap *pixmap )
 		}
 	}
 
-	if( orientation() == Qt::Vertical )
+	if( orientation() == TQt::Vertical )
 	{
 		for ( int v = 0; v < ySize; v++ )
 		{
@@ -429,7 +429,7 @@ int KColorCells::posToCell(const TQPoint &pos, bool ignoreBorders)
 
 void KColorCells::mouseMoveEvent( TQMouseEvent *e )
 {
-    if( !(e->state() & Qt::LeftButton)) return;
+    if( !(e->state() & TQt::LeftButton)) return;
 
     if(inMouse) {
         int delay = TDEGlobalSettings::dndEventDelay();
@@ -533,7 +533,7 @@ void KColorPatch::drawContents( TQPainter *painter )
 void KColorPatch::mouseMoveEvent( TQMouseEvent *e )
 {
         // Drag color object
-        if( !(e->state() & Qt::LeftButton)) return;
+        if( !(e->state() & TQt::LeftButton)) return;
 	KColorDrag *d = new KColorDrag( color, this);
 	d->dragCopy();
 }
@@ -597,12 +597,12 @@ KPaletteTable::KPaletteTable( TQWidget *parent, int minWidth, int cols)
   mNamedColorList->setFixedSize(minSize);
   mNamedColorList->hide();
   layout->addWidget(mNamedColorList);
-  connect( mNamedColorList, TQT_SIGNAL(highlighted( const TQString & )),
-	   this, TQT_SLOT( slotColorTextSelected( const TQString & )) );
+  connect( mNamedColorList, TQ_SIGNAL(highlighted( const TQString & )),
+	   this, TQ_SLOT( slotColorTextSelected( const TQString & )) );
 
   setFixedSize( sizeHint());
-  connect( combo, TQT_SIGNAL(activated(const TQString &)),
-	this, TQT_SLOT(slotSetPalette( const TQString &)));
+  connect( combo, TQ_SIGNAL(activated(const TQString &)),
+	this, TQ_SLOT(slotSetPalette( const TQString &)));
 }
 
 KPaletteTable::~KPaletteTable()
@@ -704,7 +704,7 @@ KPaletteTable::readNamedColor( void )
     // preventing the real dialog to become visible until the
     // error dialog box is removed (== bad UI).
     //
-    TQTimer::singleShot( 10, this, TQT_SLOT(slotShowNamedColorReadError()) );
+    TQTimer::singleShot( 10, this, TQ_SLOT(slotShowNamedColorReadError()) );
   }
 }
 
@@ -831,10 +831,10 @@ KPaletteTable::setPalette( const TQString &_paletteName )
       {
         cells->setColor( i, mPalette->color(i) );
       }
-      connect( cells, TQT_SIGNAL( colorSelected( int ) ),
-	       TQT_SLOT( slotColorCellSelected( int ) ) );
-      connect( cells, TQT_SIGNAL( colorDoubleClicked( int ) ),
-	       TQT_SLOT( slotColorCellDoubleClicked( int ) ) );
+      connect( cells, TQ_SIGNAL( colorSelected( int ) ),
+	       TQ_SLOT( slotColorCellSelected( int ) ) );
+      connect( cells, TQ_SIGNAL( colorDoubleClicked( int ) ),
+	       TQ_SLOT( slotColorCellDoubleClicked( int ) ) );
       sv->addChild( cells );
       cells->show();
       sv->updateScrollBars();
@@ -930,7 +930,7 @@ public:
     TQCheckBox *cbDefaultColor;
     KColor defaultColor;
     KColor selColor;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     QX11EventFilter oldfilter;
 #endif
 };
@@ -944,12 +944,12 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   d = new KColorDialogPrivate;
   d->bRecursion = true;
   d->bColorPicking = false;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
   d->oldfilter = 0;
 #endif
   d->cbDefaultColor = 0L;
-  connect( this, TQT_SIGNAL(okClicked(void)),this,TQT_SLOT(slotWriteSettings(void)));
-  connect( this, TQT_SIGNAL(closeClicked(void)),this,TQT_SLOT(slotWriteSettings(void)));
+  connect( this, TQ_SIGNAL(okClicked(void)),this,TQ_SLOT(slotWriteSettings(void)));
+  connect( this, TQ_SIGNAL(closeClicked(void)),this,TQ_SLOT(slotWriteSettings(void)));
 
   TQLabel *label;
 
@@ -981,7 +981,7 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   l_left->addSpacing(10);
 
   TQGridLayout *l_lbot = new TQGridLayout(3, 6);
-  l_left->addLayout(TQT_TQLAYOUT(l_lbot));
+  l_left->addLayout(l_lbot);
 
   //
   // the palette and value selector go into the H-box
@@ -989,14 +989,14 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   d->hsSelector = new KHSSelector( page );
   d->hsSelector->setMinimumSize(140, 70);
   l_ltop->addWidget(d->hsSelector, 8);
-  connect( d->hsSelector, TQT_SIGNAL( valueChanged( int, int ) ),
-	   TQT_SLOT( slotHSChanged( int, int ) ) );
+  connect( d->hsSelector, TQ_SIGNAL( valueChanged( int, int ) ),
+	   TQ_SLOT( slotHSChanged( int, int ) ) );
 
   d->valuePal = new KValueSelector( page );
   d->valuePal->setMinimumSize(26, 70);
   l_ltop->addWidget(d->valuePal, 1);
-  connect( d->valuePal, TQT_SIGNAL( valueChanged( int ) ),
-	   TQT_SLOT( slotVChanged( int ) ) );
+  connect( d->valuePal, TQ_SIGNAL( valueChanged( int ) ),
+	   TQ_SLOT( slotVChanged( int ) ) );
 
 
   //
@@ -1006,28 +1006,28 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget(label, 0, 2);
   d->hedit = new KColorSpinBox( 0, 359, 1, page );
-  d->hedit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->hedit) ) );
+  d->hedit->setValidator( new TQIntValidator( d->hedit ) );
   l_lbot->addWidget(d->hedit, 0, 3);
-  connect( d->hedit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotHSVChanged() ) );
+  connect( d->hedit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotHSVChanged() ) );
 
   label = new TQLabel( i18n("S:"), page );
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget(label, 1, 2);
   d->sedit = new KColorSpinBox( 0, 255, 1, page );
-  d->sedit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->sedit) ) );
+  d->sedit->setValidator( new TQIntValidator( d->sedit ) );
   l_lbot->addWidget(d->sedit, 1, 3);
-  connect( d->sedit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotHSVChanged() ) );
+  connect( d->sedit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotHSVChanged() ) );
 
   label = new TQLabel( i18n("V:"), page );
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget(label, 2, 2);
   d->vedit = new KColorSpinBox( 0, 255, 1, page );
-  d->vedit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->vedit) ) );
+  d->vedit->setValidator( new TQIntValidator( d->vedit ) );
   l_lbot->addWidget(d->vedit, 2, 3);
-  connect( d->vedit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotHSVChanged() ) );
+  connect( d->vedit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotHSVChanged() ) );
 
   //
   // add the RGB fields
@@ -1036,28 +1036,28 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget(label, 0, 4);
   d->redit = new KColorSpinBox( 0, 255, 1, page );
-  d->redit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->redit) ) );
+  d->redit->setValidator( new TQIntValidator( d->redit ) );
   l_lbot->addWidget(d->redit, 0, 5);
-  connect( d->redit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotRGBChanged() ) );
+  connect( d->redit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotRGBChanged() ) );
 
   label = new TQLabel( i18n("G:"), page );
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget( label, 1, 4);
   d->gedit = new KColorSpinBox( 0, 255,1, page );
-  d->gedit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->gedit) ) );
+  d->gedit->setValidator( new TQIntValidator( d->gedit ) );
   l_lbot->addWidget(d->gedit, 1, 5);
-  connect( d->gedit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotRGBChanged() ) );
+  connect( d->gedit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotRGBChanged() ) );
 
   label = new TQLabel( i18n("B:"), page );
   label->setAlignment(AlignRight | AlignVCenter);
   l_lbot->addWidget(label, 2, 4);
   d->bedit = new KColorSpinBox( 0, 255, 1, page );
-  d->bedit->setValidator( new TQIntValidator( TQT_TQOBJECT(d->bedit) ) );
+  d->bedit->setValidator( new TQIntValidator( d->bedit ) );
   l_lbot->addWidget(d->bedit, 2, 5);
-  connect( d->bedit, TQT_SIGNAL( valueChanged(int) ),
-  	TQT_SLOT( slotRGBChanged() ) );
+  connect( d->bedit, TQ_SIGNAL( valueChanged(int) ),
+  	TQ_SLOT( slotRGBChanged() ) );
 
   //
   // the entry fields should be wide enough to hold 8888888
@@ -1083,13 +1083,13 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   d->table = new KPaletteTable( page );
   d->l_right->addWidget(d->table, 10);
 
-  connect( d->table, TQT_SIGNAL( colorSelected( const TQColor &, const TQString & ) ),
-	   TQT_SLOT( slotColorSelected( const TQColor &, const TQString & ) ) );
+  connect( d->table, TQ_SIGNAL( colorSelected( const TQColor &, const TQString & ) ),
+	   TQ_SLOT( slotColorSelected( const TQColor &, const TQString & ) ) );
 
   connect(
     d->table,
-    TQT_SIGNAL( colorDoubleClicked( const TQColor &, const TQString & ) ),
-    TQT_SLOT( slotColorDoubleClicked( const TQColor &, const TQString & ) )
+    TQ_SIGNAL( colorDoubleClicked( const TQColor &, const TQString & ) ),
+    TQ_SLOT( slotColorDoubleClicked( const TQColor &, const TQString & ) )
   );
   // Store the default value for saving time.
   d->originalPalette = d->table->palette();
@@ -1107,7 +1107,7 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   TQPushButton *button = new TQPushButton( page );
   button->setText(i18n("&Add to Custom Colors"));
   l_hbox->addWidget(button, 0, AlignLeft);
-  connect( button, TQT_SIGNAL( clicked()), TQT_SLOT( slotAddToCustomColors()));
+  connect( button, TQ_SIGNAL( clicked()), TQ_SLOT( slotAddToCustomColors()));
 
   //
   // The color picker button
@@ -1115,7 +1115,7 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
   button = new TQPushButton( page );
   button->setPixmap( BarIcon("colorpicker"));
   l_hbox->addWidget(button, 0, AlignHCenter );
-  connect( button, TQT_SIGNAL( clicked()), TQT_SLOT( slotColorPicker()));
+  connect( button, TQ_SIGNAL( clicked()), TQ_SLOT( slotColorPicker()));
 
   //
   // a little space between
@@ -1131,30 +1131,30 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
 
   label = new TQLabel( page );
   label->setText(i18n("Name:"));
-  l_grid->addWidget(TQT_TQWIDGET(label), 0, 1, Qt::AlignLeft);
+  l_grid->addWidget(label, 0, 1, TQt::AlignLeft);
 
   d->colorName = new TQLabel( page );
-  l_grid->addWidget(TQT_TQWIDGET(d->colorName), 0, 2, Qt::AlignLeft);
+  l_grid->addWidget(d->colorName, 0, 2, TQt::AlignLeft);
 
   label = new TQLabel( page );
   label->setText(i18n("HTML:"));
-  l_grid->addWidget(TQT_TQWIDGET(label), 1, 1, Qt::AlignLeft);
+  l_grid->addWidget(label, 1, 1, TQt::AlignLeft);
 
   d->htmlName = new KLineEdit( page );
   d->htmlName->setMaxLength( 13 ); // Qt's TQColor allows 12 hexa-digits
   d->htmlName->setText("#FFFFFF"); // But HTML uses only 6, so do not worry about the size
   w = d->htmlName->fontMetrics().width(TQString::fromLatin1("#DDDDDDD"));
   d->htmlName->setFixedWidth(w);
-  l_grid->addWidget(TQT_TQWIDGET(d->htmlName), 1, 2, Qt::AlignLeft);
+  l_grid->addWidget(d->htmlName, 1, 2, TQt::AlignLeft);
 
-  connect( d->htmlName, TQT_SIGNAL( textChanged(const TQString &) ),
-      TQT_SLOT( slotHtmlChanged() ) );
+  connect( d->htmlName, TQ_SIGNAL( textChanged(const TQString &) ),
+      TQ_SLOT( slotHtmlChanged() ) );
 
   d->patch = new KColorPatch( page );
   d->patch->setFixedSize(48, 48);
-  l_grid->addMultiCellWidget(TQT_TQWIDGET(d->patch), 0, 1, 0, 0, Qt::AlignHCenter | Qt::AlignVCenter);
-  connect( d->patch, TQT_SIGNAL( colorChanged( const TQColor&)),
-	   TQT_SLOT( setColor( const TQColor&)));
+  l_grid->addMultiCellWidget(d->patch, 0, 1, 0, 0, TQt::AlignHCenter | TQt::AlignVCenter);
+  connect( d->patch, TQ_SIGNAL( colorChanged( const TQColor&)),
+	   TQ_SLOT( setColor( const TQColor&)));
 
   tl_layout->activate();
   page->setMinimumSize( page->sizeHint() );
@@ -1177,7 +1177,7 @@ KColorDialog::KColorDialog( TQWidget *parent, const char *name, bool modal )
 
 KColorDialog::~KColorDialog()
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if (d->bColorPicking)
         tqt_set_x11_event_filter(d->oldfilter);
 #endif
@@ -1226,7 +1226,7 @@ KColorDialog::setDefaultColor( const TQColor& col )
         mainWidget()->setMinimumSize( mainWidget()->sizeHint() );
         disableResize();
 
-        connect( d->cbDefaultColor, TQT_SIGNAL( clicked() ), TQT_SLOT( slotDefaultColorClicked() ) );
+        connect( d->cbDefaultColor, TQ_SIGNAL( clicked() ), TQ_SLOT( slotDefaultColorClicked() ) );
     }
 
     d->defaultColor = col;
@@ -1486,7 +1486,7 @@ void KColorDialog::showColor( const KColor &color, const TQString &name )
 
 static TQWidget *kde_color_dlg_widget = 0;
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 static int kde_color_dlg_handler(XEvent *event)
 {
     if (event->type == ButtonRelease)
@@ -1503,11 +1503,11 @@ void
 KColorDialog::slotColorPicker()
 {
     d->bColorPicking = true;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     d->oldfilter = tqt_set_x11_event_filter(kde_color_dlg_handler);
 #endif
     kde_color_dlg_widget = this;
-    grabMouse( tqcrossCursor );
+    grabMouse( TQt::crossCursor );
     grabKeyboard();
 }
 
@@ -1517,7 +1517,7 @@ KColorDialog::mouseReleaseEvent( TQMouseEvent *e )
   if (d->bColorPicking)
   {
      d->bColorPicking = false;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
      tqt_set_x11_event_filter(d->oldfilter);
      d->oldfilter = 0;
 #endif
@@ -1532,7 +1532,7 @@ KColorDialog::mouseReleaseEvent( TQMouseEvent *e )
 TQColor
 KColorDialog::grabColor(const TQPoint &p)
 {
-    TQWidget *desktop = TQT_TQWIDGET(TQApplication::desktop());
+    TQWidget *desktop = TQApplication::desktop();
     TQPixmap pm = TQPixmap::grabWindow( desktop->winId(), p.x(), p.y(), 1, 1);
     TQImage i = pm.convertToImage();
     return i.pixel(0,0);
@@ -1546,7 +1546,7 @@ KColorDialog::keyPressEvent( TQKeyEvent *e )
      if (e->key() == Key_Escape)
      {
         d->bColorPicking = false;
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
         tqt_set_x11_event_filter(d->oldfilter);
         d->oldfilter = 0;
 #endif
