@@ -54,7 +54,7 @@
 #include <tdeaboutdata.h>
 #include <kstaticdeleter.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #define XK_XKB_KEYS
 #define XK_MISCELLANY
 #include <X11/Xlib.h>	// For x11Event()
@@ -326,7 +326,7 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   TDEListViewSearchLine* listViewSearch = new TDEListViewSearchLine(this);
   searchLayout->addWidget(listViewSearch);
   slbl->setBuddy(listViewSearch);
-  connect(clearSearch, TQT_SIGNAL(pressed()), listViewSearch, TQT_SLOT(clear()));
+  connect(clearSearch, TQ_SIGNAL(pressed()), listViewSearch, TQ_SLOT(clear()));
 
   TQString wtstr = i18n("Search interactively for shortcut names (e.g. Copy) "
                        "or combination of keys (e.g. Ctrl+C) by typing them here.");
@@ -340,7 +340,7 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   // fill up the split list box with the action/key pairs.
   //
   TQGridLayout *stackLayout = new TQGridLayout(2, 2, 2);
-  topLayout->addLayout( TQT_TQLAYOUT(stackLayout), 10 );
+  topLayout->addLayout( stackLayout, 10 );
   stackLayout->setRowStretch( 1, 10 ); // Only list will stretch
 
   d->pList = new TDEListView( this );
@@ -364,13 +364,13 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   d->pList->addColumn(i18n("Shortcut"));
   d->pList->addColumn(i18n("Alternate"));
 
-  connect( d->pList, TQT_SIGNAL(currentChanged(TQListViewItem*)),
-           TQT_SLOT(slotListItemSelected(TQListViewItem*)) );
+  connect( d->pList, TQ_SIGNAL(currentChanged(TQListViewItem*)),
+           TQ_SLOT(slotListItemSelected(TQListViewItem*)) );
 
   // handle double clicking an item
-  connect ( d->pList, TQT_SIGNAL ( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ),
-                       TQT_SLOT ( captureCurrentItem()) );
-  connect ( d->pList, TQT_SIGNAL ( spacePressed( TQListViewItem* )), TQT_SLOT( captureCurrentItem()));
+  connect ( d->pList, TQ_SIGNAL ( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ),
+                       TQ_SLOT ( captureCurrentItem()) );
+  connect ( d->pList, TQ_SIGNAL ( spacePressed( TQListViewItem* )), TQ_SLOT( captureCurrentItem()));
   //
   // CREATE CHOOSE KEY GROUP
   //
@@ -396,7 +396,7 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   //grid->addMultiCellWidget( rb, 1, 1, 1, 2 );
   grid->addWidget( m_prbNone, 1, 0 );
   TQWhatsThis::add( m_prbNone, i18n("The selected action will not be associated with any key.") );
-  connect( m_prbNone, TQT_SIGNAL(clicked()), TQT_SLOT(slotNoKey()) );
+  connect( m_prbNone, TQ_SIGNAL(clicked()), TQ_SLOT(slotNoKey()) );
 
   m_prbDef = new TQRadioButton( i18n("default key", "De&fault"), d->fCArea );
   d->kbGroup->insert( m_prbDef, DefaultKey );
@@ -404,7 +404,7 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   //grid->addMultiCellWidget( rb, 2, 2, 1, 2 );
   grid->addWidget( m_prbDef, 1, 1 );
   TQWhatsThis::add( m_prbDef, i18n("This will bind the default key to the selected action. Usually a reasonable choice.") );
-  connect( m_prbDef, TQT_SIGNAL(clicked()), TQT_SLOT(slotDefaultKey()) );
+  connect( m_prbDef, TQ_SIGNAL(clicked()), TQ_SLOT(slotDefaultKey()) );
 
   m_prbCustom = new TQRadioButton( i18n("C&ustom"), d->fCArea );
   d->kbGroup->insert( m_prbCustom, CustomKey );
@@ -413,16 +413,16 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   grid->addWidget( m_prbCustom, 1, 2 );
   TQWhatsThis::add( m_prbCustom, i18n("If this option is selected you can create a customized key binding for the"
     " selected action using the buttons below.") );
-  connect( m_prbCustom, TQT_SIGNAL(clicked()), TQT_SLOT(slotCustomKey()) );
+  connect( m_prbCustom, TQ_SIGNAL(clicked()), TQ_SLOT(slotCustomKey()) );
 
-  //connect( d->kbGroup, TQT_SIGNAL( clicked( int ) ), TQT_SLOT( keyMode( int ) ) );
+  //connect( d->kbGroup, TQ_SIGNAL( clicked( int ) ), TQ_SLOT( keyMode( int ) ) );
 
   TQBoxLayout *pushLayout = new TQHBoxLayout( KDialog::spacingHint() );
   grid->addLayout( pushLayout, 1, 3 );
 
   d->pbtnShortcut = new KKeyButton(d->fCArea, "key");
   d->pbtnShortcut->setEnabled( false );
-  connect( d->pbtnShortcut, TQT_SIGNAL(capturedShortcut(const TDEShortcut&)), TQT_SLOT(capturedShortcut(const TDEShortcut&)) );
+  connect( d->pbtnShortcut, TQ_SIGNAL(capturedShortcut(const TDEShortcut&)), TQ_SLOT(capturedShortcut(const TDEShortcut&)) );
   grid->addRowSpacing( 1, d->pbtnShortcut->sizeHint().height() + 5 );
 
   wtstr = i18n("Use this button to choose a new shortcut key. Once you click it, "
@@ -451,7 +451,7 @@ void KKeyChooser::initGUI( ActionType type, bool bAllowLetterShortcuts )
   //d->stdDict->setAutoDelete( true );
   //if (type == Application || type == ApplicationGlobal)
   //  readStdKeys();
-  connect( kapp, TQT_SIGNAL( settingsChanged( int )), TQT_SLOT( slotSettingsChanged( int )));
+  connect( kapp, TQ_SIGNAL( settingsChanged( int )), TQ_SLOT( slotSettingsChanged( int )));
   if( allChoosers == NULL )
         allChoosers = allChoosersDeleter.setObject( allChoosers, new TQValueList< KKeyChooser* > );
   allChoosers->append( this );
@@ -1092,7 +1092,7 @@ KKeyDialog::KKeyDialog( KKeyChooser::ActionType type, bool bAllowLetterShortcuts
 {
 	m_pKeyChooser = new KKeyChooser( this, type, bAllowLetterShortcuts );
 	setMainWidget( m_pKeyChooser );
-	connect( this, TQT_SIGNAL(defaultClicked()), m_pKeyChooser, TQT_SLOT(allDefault()) );
+	connect( this, TQ_SIGNAL(defaultClicked()), m_pKeyChooser, TQ_SLOT(allDefault()) );
 
 	TDEConfigGroup group( TDEGlobal::config(), "KKeyDialog Settings" );
 	TQSize sz = size();
@@ -1104,7 +1104,7 @@ KKeyDialog::KKeyDialog( bool bAllowLetterShortcuts, TQWidget *parent, const char
 {
 	m_pKeyChooser = new KKeyChooser( this, KKeyChooser::Application, bAllowLetterShortcuts );
 	setMainWidget( m_pKeyChooser );
-	connect( this, TQT_SIGNAL(defaultClicked()), m_pKeyChooser, TQT_SLOT(allDefault()) );
+	connect( this, TQ_SIGNAL(defaultClicked()), m_pKeyChooser, TQ_SLOT(allDefault()) );
 
 	TDEConfigGroup group( TDEGlobal::config(), "KKeyDialog Settings" );
 	TQSize sz = size();
