@@ -101,18 +101,18 @@ KSpellConfig::KSpellConfig( TQWidget *parent, const char *name,
   TQGridLayout *glay = new TQGridLayout( this, 6, 3, 0, KDialog::spacingHint() );
   cb1 = new TQCheckBox( i18n("Create &root/affix combinations"
                             " not in dictionary"), this, "NoRootAffix" );
-  connect( cb1, TQT_SIGNAL(toggled(bool)), TQT_SLOT(sNoAff(bool)) );
+  connect( cb1, TQ_SIGNAL(toggled(bool)), TQ_SLOT(sNoAff(bool)) );
   glay->addMultiCellWidget( cb1, 0, 0, 0, 2 );
 
   cb2 = new TQCheckBox( i18n("Consider run-together &words"
 			    " as spelling errors"), this, "RunTogether" );
-  connect( cb2, TQT_SIGNAL(toggled(bool)), TQT_SLOT(sRunTogether(bool)) );
+  connect( cb2, TQ_SIGNAL(toggled(bool)), TQ_SLOT(sRunTogether(bool)) );
   glay->addMultiCellWidget( cb2, 1, 1, 0, 2 );
 
   dictcombo = new TQComboBox( this, "DictFromList" );
   dictcombo->setInsertionPolicy( TQComboBox::NoInsertion );
-  connect( dictcombo, TQT_SIGNAL (activated(int)),
-	   this, TQT_SLOT (sSetDictionary(int)) );
+  connect( dictcombo, TQ_SIGNAL (activated(int)),
+	   this, TQ_SLOT (sSetDictionary(int)) );
   glay->addMultiCellWidget( dictcombo, 2, 2, 1, 2 );
 
   dictlist = new TQLabel( dictcombo, i18n("&Dictionary:"), this );
@@ -136,8 +136,8 @@ KSpellConfig::KSpellConfig( TQWidget *parent, const char *name,
   encodingcombo->insertItem( "CP1251" );
   encodingcombo->insertItem( "CP1255" );
 
-  connect( encodingcombo, TQT_SIGNAL(activated(int)), this,
-	   TQT_SLOT(sChangeEncoding(int)) );
+  connect( encodingcombo, TQ_SIGNAL(activated(int)), this,
+	   TQ_SLOT(sChangeEncoding(int)) );
   glay->addMultiCellWidget( encodingcombo, 3, 3, 1, 2 );
 
   TQLabel *tmpQLabel = new TQLabel( encodingcombo, i18n("&Encoding:"), this);
@@ -149,8 +149,8 @@ KSpellConfig::KSpellConfig( TQWidget *parent, const char *name,
   clientcombo->insertItem( i18n("Aspell") );
   clientcombo->insertItem( i18n("Hspell") );
   clientcombo->insertItem( i18n("Zemberek") );
-  connect( clientcombo, TQT_SIGNAL (activated(int)), this,
-	   TQT_SLOT (sChangeClient(int)) );
+  connect( clientcombo, TQ_SIGNAL (activated(int)), this,
+	   TQ_SLOT (sChangeClient(int)) );
   glay->addMultiCellWidget( clientcombo, 4, 4, 1, 2 );
 
   tmpQLabel = new TQLabel( clientcombo, i18n("&Client:"), this );
@@ -159,7 +159,7 @@ KSpellConfig::KSpellConfig( TQWidget *parent, const char *name,
   if( addHelpButton )
   {
     TQPushButton *pushButton = new KPushButton( KStdGuiItem::help(), this );
-    connect( pushButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(sHelp()) );
+    connect( pushButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(sHelp()) );
     glay->addWidget(pushButton, 5, 2);
   }
 
@@ -926,7 +926,7 @@ KSpellConfig::sSetDictionary (int i)
 {
   setDictionary (langfnames[i]);
   setDictFromList (true);
-  TQTimer::singleShot( 0, this, TQT_SIGNAL( configChanged() ) );
+  TQTimer::singleShot( 0, this, TQ_SIGNAL( configChanged() ) );
 }
 
 void
