@@ -499,7 +499,7 @@ namespace KStdAction
 	* @since 3.1
 	*/
 	TDEUI_EXPORT TDEToggleAction *showToolbar(const TQObject *recvr, const char *slot,
-					TDEActionCollection* parent, const char *name = 0 ) KDE_DEPRECATED;
+					TDEActionCollection* parent, const char *name = 0 ) TDE_DEPRECATED;
 	/**
 	* @obsolete. toolbar actions are created automatically now in the
 	* Settings menu. Don't use this anymore.
@@ -507,7 +507,7 @@ namespace KStdAction
 	* Show/Hide the primary toolbar.
 	*/
 	TDEUI_EXPORT TDEToggleToolBarAction *showToolbar(const char* toolBarName,
-					TDEActionCollection* parent, const char *name = 0 ) KDE_DEPRECATED;
+					TDEActionCollection* parent, const char *name = 0 ) TDE_DEPRECATED;
 
 	/**
 	* Show/Hide the statusbar.
