@@ -98,7 +98,7 @@ void TDECModule::init()
 TDEConfigDialogManager* TDECModule::addConfig( TDEConfigSkeleton *config, TQWidget* widget )
 {
     TDEConfigDialogManager* manager = new TDEConfigDialogManager( widget, config, name() );
-    connect( manager, TQT_SIGNAL( widgetModified() ), TQT_SLOT( widgetChanged() ));
+    connect( manager, TQ_SIGNAL( widgetModified() ), TQ_SLOT( widgetChanged() ));
     d->managers.append( manager );
     return manager;
 }
