@@ -85,7 +85,7 @@ class TDEUI_EXPORT TDEListView : public TQListView
 {
   friend class TDEListViewItem;
 
-  Q_OBJECT
+  TQ_OBJECT
   
   TQ_ENUMS( SelectionModeExt )
   TQ_PROPERTY( bool fullWidth READ fullWidth WRITE setFullWidth )
@@ -286,7 +286,7 @@ public:
    * Do not use.
    * @deprecated
    */
-  bool createChildren() const KDE_DEPRECATED;
+  bool createChildren() const TDE_DEPRECATED;
 
   /**
    * @return true if drawing of the drop-highlighter has been enabled.  False by default.
@@ -329,7 +329,7 @@ public:
    * @deprecated
    * @see setFullWidth()
    */
-  void setFullWidth() KDE_DEPRECATED;
+  void setFullWidth() TDE_DEPRECATED;
 
   /**
    * Let the last column fit exactly all the available width.
@@ -723,7 +723,7 @@ public slots:
    * Do not use.
    * @deprecated
    */
-  virtual void setCreateChildren(bool b) KDE_DEPRECATED;
+  virtual void setCreateChildren(bool b) TDE_DEPRECATED;
 
   /**
    * Set the selection mode.
@@ -1165,7 +1165,7 @@ public:
   /**
    * returns the background color for this item
    */
-  const TQColor &backgroundColor() KDE_DEPRECATED;  // #### should be removed in 4.0; use below instead
+  const TQColor &backgroundColor() TDE_DEPRECATED;  // #### should be removed in 4.0; use below instead
 
   /**
    * returns the background color for this item at given column
