@@ -86,7 +86,7 @@ void TDEPopupTitle::paintEvent(TQPaintEvent *)
 {
     TQRect r(rect());
     TQPainter p(this);
-    kapp->style().tqdrawPrimitive(TQStyle::PE_HeaderSectionMenu, &p, r, palette().active());
+    kapp->style().drawPrimitive(TQStyle::PE_HeaderSectionMenu, &p, r, palette().active());
 
     if (!miniicon.isNull())
         p.drawPixmap(4, (r.height()-miniicon.height())/2, miniicon);
@@ -124,7 +124,7 @@ public:
         , shortcuts(false)
         , autoExec(false)
         , lastHitIndex(-1)
-        , state(Qt::NoButton)
+        , state(TQt::NoButton)
         , m_ctxMenu(0)
     {}
 
@@ -164,7 +164,7 @@ TDEPopupMenu::TDEPopupMenu(TQWidget *parent, const char *name)
 {
     d = new TDEPopupMenuPrivate;
     resetKeyboardVars();
-    connect(&(d->clearTimer), TQT_SIGNAL(timeout()), TQT_SLOT(resetKeyboardVars()));
+    connect(&(d->clearTimer), TQ_SIGNAL(timeout()), TQ_SLOT(resetKeyboardVars()));
 }
 
 TDEPopupMenu::~TDEPopupMenu()
@@ -274,7 +274,7 @@ void TDEPopupMenu::closeEvent(TQCloseEvent*e)
 
 void TDEPopupMenu::activateItemAt(int index)
 {
-    d->state = Qt::NoButton;
+    d->state = TQt::NoButton;
     TQPopupMenu::activateItemAt(index);
 }
 
@@ -285,7 +285,7 @@ TQt::ButtonState TDEPopupMenu::state() const
 
 void TDEPopupMenu::keyPressEvent(TQKeyEvent* e)
 {
-    d->state = Qt::NoButton;
+    d->state = TQt::NoButton;
     if (!d->shortcuts) {
         // continue event processing by Qpopup
         //e->ignore();
@@ -514,7 +514,7 @@ TQPopupMenu* TDEPopupMenu::contextMenu()
     if (!d->m_ctxMenu)
     {
         d->m_ctxMenu = new TQPopupMenu(this);
-        connect(d->m_ctxMenu, TQT_SIGNAL(aboutToHide()), this, TQT_SLOT(ctxMenuHiding()));
+        connect(d->m_ctxMenu, TQ_SIGNAL(aboutToHide()), this, TQ_SLOT(ctxMenuHiding()));
     }
 
     return d->m_ctxMenu;
@@ -559,7 +559,7 @@ void TDEPopupMenu::showCtxMenu(TQPoint pos)
         TQPopupMenu* subMenu = item->popup();
         if (subMenu)
         {
-            disconnect(subMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(ctxMenuHideShowingMenu()));
+            disconnect(subMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(ctxMenuHideShowingMenu()));
         }
     }
 
@@ -576,8 +576,8 @@ void TDEPopupMenu::showCtxMenu(TQPoint pos)
     TQPopupMenu* subMenu = findItem(TDEPopupMenuPrivate::s_highlightedItem)->popup();
     if (subMenu)
     {
-        connect(subMenu, TQT_SIGNAL(aboutToShow()), TQT_SLOT(ctxMenuHideShowingMenu()));
-        TQTimer::singleShot(100, subMenu, TQT_SLOT(hide()));
+        connect(subMenu, TQ_SIGNAL(aboutToShow()), TQ_SLOT(ctxMenuHideShowingMenu()));
+        TQTimer::singleShot(100, subMenu, TQ_SLOT(hide()));
     }
 
     if (!TDEPopupMenuPrivate::s_continueCtxMenuShow)
@@ -588,7 +588,7 @@ void TDEPopupMenu::showCtxMenu(TQPoint pos)
 
     TDEPopupMenuPrivate::s_contextedMenu = this;
     d->m_ctxMenu->popup(this->mapToGlobal(pos));
-    connect(this, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(itemHighlighted(int)));
+    connect(this, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(itemHighlighted(int)));
 }
 
 /*
@@ -603,7 +603,7 @@ void TDEPopupMenu::ctxMenuHideShowingMenu()
         TQPopupMenu* subMenu = item->popup();
         if (subMenu)
         {
-            TQTimer::singleShot(0, subMenu, TQT_SLOT(hide()));
+            TQTimer::singleShot(0, subMenu, TQ_SLOT(hide()));
         }
     }
 }
@@ -615,11 +615,11 @@ void TDEPopupMenu::ctxMenuHiding()
         TQPopupMenu* subMenu = findItem(TDEPopupMenuPrivate::s_highlightedItem)->popup();
         if (subMenu)
         {
-            disconnect(subMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(ctxMenuHideShowingMenu()));
+            disconnect(subMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(ctxMenuHideShowingMenu()));
         }
     }
 
-    disconnect(this, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(itemHighlighted(int)));
+    disconnect(this, TQ_SIGNAL(highlighted(int)), this, TQ_SLOT(itemHighlighted(int)));
     TDEPopupMenuPrivate::s_continueCtxMenuShow = true;
 }
 
