@@ -11,7 +11,7 @@ class KLineEdit;
 
 class KLineEditTest : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
    KLineEditTest( TQWidget *parent=0, const char *name=0 );
