@@ -6,7 +6,7 @@
 
 class TestWidget : public TQLabel
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     TestWidget(TQWidget *parent=0, const char *name=0);
     ~TestWidget(){delete testMenu;}
