@@ -102,7 +102,7 @@ public:
     KCMultiDialog( int dialogFace, const KGuiItem &user2,
             const KGuiItem &user3=KGuiItem(), int buttonMask=User2,
             const TQString &caption=i18n("Configure"), TQWidget *parent=0,
-            const char *name=0, bool modal=false ) KDE_DEPRECATED;
+            const char *name=0, bool modal=false ) TDE_DEPRECATED;
     // KDE4 remove the user3 argument, and instead initialize it to KStdGuiItem::adminMode.
 
     /**
