@@ -22,11 +22,11 @@ void openWallet()
 	TDEWallet::Wallet *wallet = TDEWallet::Wallet::openWallet( TDEWallet::Wallet::NetworkWallet(), 0, TDEWallet::Wallet::Asynchronous );
 
 	WalletReceiver r;
-	r.connect( wallet, TQT_SIGNAL( walletOpened(bool) ), TQT_SLOT( walletOpened(bool) ) );
+	r.connect( wallet, TQ_SIGNAL( walletOpened(bool) ), TQ_SLOT( walletOpened(bool) ) );
 
 	_out << "About to start 30 second event loop" << endl;
 
-	TQTimer::singleShot( 30000, tqApp, TQT_SLOT( quit() ) );
+	TQTimer::singleShot( 30000, tqApp, TQ_SLOT( quit() ) );
 	int ret = tqApp->exec();
 
 	if ( ret == 0 )
